--
-- PostgreSQL database dump
--

SET client_encoding = 'SQL_ASCII';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

--
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: -
--

COMMENT ON SCHEMA public IS 'Standard public schema';


SET search_path = public, pg_catalog;

--
-- Name: _user; Type: TYPE; Schema: public; Owner: -
--

DROP TYPE _user CASCADE;

CREATE TYPE _user AS (
	id integer,
	name text
);

ALTER TYPE _user OWNER TO selinks;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: block_format; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

DROP TABLE block_format CASCADE;

CREATE TABLE block_format (
    pageid integer NOT NULL,
    blockid integer NOT NULL,
    formattag character varying(1024),
    userid integer NOT NULL
);

ALTER Table block_format OWNER TO selinks;

--
-- Name: block_label; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

DROP TABLE block_label CASCADE;

CREATE TABLE block_label (
    pageid integer NOT NULL,
    blockid integer NOT NULL,
    label text
);

ALTER TABLE block_label OWNER TO selinks;

--
-- Name: blockid_sequence; Type: SEQUENCE; Schema: public; Owner: -
--

DROP SEQUENCE blockid_sequence CASCADE;

CREATE SEQUENCE blockid_sequence
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;

--
-- Name: blockid_sequence; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('blockid_sequence', 27258, true);


--
-- Name: page_blocks; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

DROP TABLE page_blocks CASCADE;

CREATE TABLE page_blocks (
    blockid integer DEFAULT nextval('blockid_sequence'::regclass) NOT NULL,
    pageid integer NOT NULL,
    parentblockid integer,
    blocktype character varying(32) NOT NULL,
    text text,
    sibling integer,
    current boolean,
    CONSTRAINT page_blocks_blocktype_check CHECK (((blocktype)::text = ANY ((ARRAY['formatted'::character varying, 'labeled'::character varying, 'word'::character varying, 'compound'::character varying])::text[])))
);

ALTER TABLE page_blocks OWNER TO selinks;

--
-- Name: pageid_sequence; Type: SEQUENCE; Schema: public; Owner: -
--

DROP SEQUENCE pageid_sequence CASCADE;

CREATE SEQUENCE pageid_sequence
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;

--
-- Name: pageid_sequence; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('pageid_sequence', 824, true);


--
-- Name: pages; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

DROP TABLE pages CASCADE;

CREATE TABLE pages (
    pageid integer DEFAULT nextval('pageid_sequence'::regclass) NOT NULL,
    creator integer,
    title character varying(64)
);

ALTER TABLE pages OWNER TO selinks;

--
-- Name: tag_user_xref; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

DROP TABLE tag_user_xref CASCADE;

CREATE TABLE tag_user_xref (
    tagid integer NOT NULL,
    userid integer NOT NULL
);

ALTER TABLE tag_user_xref OWNER TO selinks;

--
-- Name: tags; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

DROP TABLE tags CASCADE;

CREATE TABLE tags (
    tagid integer NOT NULL,
    "owner" integer,
    name character varying(80)
);

ALTER TABLE tags OWNER TO selinks;

--
-- Name: tags_tagid_seq; Type: SEQUENCE; Schema: public; Owner: -
--

DROP SEQUENCE tags_tagid_seq CASCADE;

CREATE SEQUENCE tags_tagid_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;

--
-- Name: tags_tagid_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--


--
-- Name: tags_tagid_seq; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('tags_tagid_seq', 6, true);


--
-- Name: userid_sequence; Type: SEQUENCE; Schema: public; Owner: -
--

DROP SEQUENCE userid_sequence CASCADE;

CREATE SEQUENCE userid_sequence
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;

--
-- Name: userid_sequence; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('userid_sequence', 34, true);


--
-- Name: users; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

DROP TABLE users CASCADE;

CREATE TABLE users (
    name character varying(30),
    "password" character varying(30),
    credential integer,
    userid integer DEFAULT nextval('userid_sequence'::regclass) NOT NULL
);

ALTER TABLE users OWNER TO selinks;

--
-- Name: tagid; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE tags ALTER COLUMN tagid SET DEFAULT nextval('tags_tagid_seq'::regclass);


--
-- Data for Name: block_format; Type: TABLE DATA; Schema: public; Owner: -
--

COPY block_format (pageid, blockid, formattag, userid) FROM stdin;
776	20330	BARFbXBoAwA=	30
776	20333	BAJXUwQEUGFyYQMA	30
776	20336	BAJXUwQEUGFyYQMA	30
776	20339	BARCb2xkAwA=	30
776	20342	BARFbXBoAwA=	30
776	20345	BARCb2xkAwA=	30
776	20348	BARCb2xkAwA=	30
776	20351	BAJXUwQEUGFyYQMA	30
776	20356	BARMaW5rBgkIAWMIAXAIAWEIAS4IAWwIAWkIAW4IAWsIAXM=	30
776	20359	BARFbXBoAwA=	30
776	20362	BAJXUwQEUGFyYQMA	30
776	20365	BAhXaWtpTGluawMA	30
776	20367	BAJXUwQEUGFyYQMA	30
780	20797	BAJXUwQEUGFyYQMA	30
780	20802	BARMaXN0AwA=	30
780	20804	BAZJbmRlbnQIBQEw	30
780	20805	BApPcmRlcmVkRWx0BgIIATEIAS4=	30
780	20807	BAhXaWtpTGluawMA	30
780	20811	BAZJbmRlbnQIBQEw	30
780	20812	BApPcmRlcmVkRWx0BgIIATIIAS4=	30
780	20814	BAhXaWtpTGluawMA	30
780	20818	BAZJbmRlbnQIBQEw	30
780	20819	BApPcmRlcmVkRWx0BgIIATMIAS4=	30
780	20821	BAhXaWtpTGluawMA	30
782	20853	BARMaW5rBjEIAWgIAXQIAXQIAXAIAToIAS8IAS8IAXcIAXcIAXcIAS4IAWMIAXMIAS4IAXUIAW0IAWQIAS4IAWUIAWQIAXUIAS8IAX4IAW4IAXMIAXcIAWEIAW0IAXkIAS8IAXAIAWEIAXAIAWUIAXIIAXMIAS8IAWYIAWEIAWIIAWwIAWUIAS0IAXQIAXIIAS4IAXAIAWQIAWY=	30
782	20856	BARFbXBoAwA=	30
782	20859	BARFbXBoAwA=	30
782	20862	BAJXUwQEUGFyYQMA	30
782	20865	BAhXaWtpTGluawMA	30
784	21244	BAJXUwQEUGFyYQMA	30
784	21249	BARMaXN0AwA=	30
784	21251	BAZJbmRlbnQIBQEw	30
784	21252	BApPcmRlcmVkRWx0BgIIATEIAS4=	30
784	21254	BAhXaWtpTGluawMA	30
784	21258	BAZJbmRlbnQIBQEw	30
784	21259	BApPcmRlcmVkRWx0BgIIATIIAS4=	30
784	21261	BAhXaWtpTGluawMA	30
784	21265	BAZJbmRlbnQIBQEw	30
784	21266	BApPcmRlcmVkRWx0BgIIATMIAS4=	30
784	21268	BAhXaWtpTGluawMA	30
784	21272	BAZJbmRlbnQIBQEw	30
784	21273	BApPcmRlcmVkRWx0BgIIATQIAS4=	30
784	21275	BAhXaWtpTGluawMA	30
784	21279	BAZJbmRlbnQIBQEw	30
784	21280	BApPcmRlcmVkRWx0BgIIATUIAS4=	30
784	21282	BAhXaWtpTGluawMA	30
784	21286	BAJXUwQEUGFyYQMA	30
790	23693	BAJXUwQEUGFyYQMA	30
790	23698	BARMaXN0AwA=	30
790	23700	BAZJbmRlbnQIBQEw	30
790	23701	BAxVbm9yZGVyZWRFbHQGAQgBKg==	30
790	23706	BAZJbmRlbnQIBQEw	30
790	23707	BAxVbm9yZGVyZWRFbHQGAQgBKg==	30
790	23712	BAZJbmRlbnQIBQEw	30
790	23713	BAxVbm9yZGVyZWRFbHQGAQgBKg==	30
790	23718	BAZJbmRlbnQIBQEw	30
790	23719	BAxVbm9yZGVyZWRFbHQGAQgBKg==	30
790	23726	BARIZHIyAwA=	30
790	23728	BAJXUwQEUGFyYQMA	30
790	23731	BAJXUwQEUGFyYQMA	30
790	23736	BApCbG9ja1F1b3RlAwA=	30
790	23741	BAlJbWFnZUxpbmsGNAgBaAgBdAgBdAgBcAgBOggBLwgBLwgBdwgBdwgBdwgBLggBYwgBcwgBLggBdQgBbQgBZAgBLggBZQgBZAgBdQgBLwgBYQgBcwgBcwgBZQgBdAgBcwgBLwgBaQgBbQgBYQgBZwgBZQgBcwgBLwgBbAgBbwgBZwgBbwgBcwgBLwgBZwgBbAgBbwgBYggBZQgBMggBLggBZwgBaQgBZg==	30
790	23743	BAJXUwQEUGFyYQMA	30
790	23746	BARFbXBoAwA=	30
790	23753	BAJXUwQEUGFyYQMA	30
790	23755	BARIZHIyAwA=	30
790	23757	BAJXUwQEUGFyYQMA	30
790	23759	BARCb2xkAwA=	30
790	23762	BAJXUwQEUGFyYQMA	30
790	23765	BAJXUwQEUGFyYQMA	30
790	23768	BAJXUwQEUGFyYQMA	30
790	23773	BApCbG9ja1F1b3RlAwA=	30
790	23777	BAJXUwQEUGFyYQMA	30
790	23782	BARMaXN0AwA=	30
790	23784	BAZJbmRlbnQIBQEw	30
790	23785	BAxVbm9yZGVyZWRFbHQGAQgBKg==	30
790	23790	BAZJbmRlbnQIBQEw	30
790	23791	BAxVbm9yZGVyZWRFbHQGAQgBKg==	30
790	23796	BAJXUwQEUGFyYQMA	30
790	23801	BApCbG9ja1F1b3RlAwA=	30
790	23805	BAJXUwQEUGFyYQMA	30
790	23810	BARMaXN0AwA=	30
790	23812	BAZJbmRlbnQIBQEw	30
790	23813	BApPcmRlcmVkRWx0BgIIATEIAS4=	30
790	23818	BAZJbmRlbnQIBQEw	30
790	23819	BApPcmRlcmVkRWx0BgIIATIIAS4=	30
790	23824	BAJXUwQEUGFyYQMA	30
790	23831	BAJXUwQEUGFyYQMA	30
790	23836	BApCbG9ja1F1b3RlAwA=	30
790	23843	BAJXUwQEUGFyYQMA	30
790	23848	BARMaXN0AwA=	30
790	23850	BAZJbmRlbnQIBQEw	30
790	23851	BApPcmRlcmVkRWx0BgIIATEIAS4=	30
790	23856	BAZJbmRlbnQIBQEx	30
790	23857	BAxVbm9yZGVyZWRFbHQGAQgBKg==	30
790	23862	BAZJbmRlbnQIBQEx	30
790	23863	BAxVbm9yZGVyZWRFbHQGAQgBKg==	30
790	23868	BAZJbmRlbnQIBQEw	30
790	23869	BApPcmRlcmVkRWx0BgIIATIIAS4=	30
790	23874	BAZJbmRlbnQIBQEw	30
790	23875	BApPcmRlcmVkRWx0BgIIATMIAS4=	30
790	23880	BAJXUwQEUGFyYQMA	30
790	23882	BARIZHIyAwA=	30
790	23884	BAJXUwQEUGFyYQMA	30
790	23887	BAJXUwQEUGFyYQMA	30
790	23892	BApCbG9ja1F1b3RlAwA=	30
790	23897	BAJXUwQFSExpbmUDAA==	30
790	23899	BAJXUwQEUGFyYQMA	30
790	23903	BARIZHIyAwA=	30
790	23905	BAJXUwQEUGFyYQMA	30
790	23908	BARFbXBoAwA=	30
790	23913	BAJXUwQEUGFyYQMA	30
790	23918	BApCbG9ja1F1b3RlAwA=	30
790	23921	BAJXUwQEUGFyYQMA	30
790	23926	BApCbG9ja1F1b3RlAwA=	30
790	23931	BAJXUwQFSExpbmUDAA==	30
790	23933	BAJXUwQEUGFyYQMA	30
790	23938	BAhXaWtpTGluawMA	30
786	24544	BARIZHIxAwA=	1
786	24546	BAJXUwQEUGFyYQMA	1
786	24549	BAJXUwQEUGFyYQMA	1
786	24552	BARMaW5rBgkIAWMIAXAIAWEIAS4IAWwIAWkIAW4IAWsIAXM=	1
786	24555	BARFbXBoAwA=	1
786	24558	BARFbXBoAwA=	1
786	24561	BAJXUwQEUGFyYQMA	1
786	24563	BARIZHIyAwA=	1
786	24565	BAJXUwQEUGFyYQMA	1
786	24568	BARCb2xkAwA=	1
786	24571	BARFbXBoAwA=	1
786	24574	BARCb2xkAwA=	1
786	24577	BAJXUwQEUGFyYQMA	1
786	24580	BAJXUwQEUGFyYQMA	1
786	24582	BARIZHIyAwA=	1
786	24584	BAJXUwQEUGFyYQMA	1
786	24587	BARCb2xkAwA=	1
786	24590	BARCb2xkAwA=	1
786	24593	BAJXUwQEUGFyYQMA	1
786	24596	BARCb2xkAwA=	1
786	24599	BAJXUwQEUGFyYQMA	1
786	24602	BAhXaWtpTGluawMA	1
787	25063	BAJXUwQEUGFyYQMA	1
787	25065	BARIZHIxAwA=	1
787	25067	BAJXUwQEUGFyYQMA	1
787	25069	BARIZHIyAwA=	1
787	25071	BAJXUwQEUGFyYQMA	1
787	25074	BAJXUwQEUGFyYQMA	1
787	25079	BApCbG9ja1F1b3RlAwA=	1
787	25084	BARFbXBoAwA=	1
787	25087	BARFbXBoAwA=	1
787	25089	BAJXUwQEUGFyYQMA	1
787	25091	BARIZHIyAwA=	1
787	25093	BAJXUwQEUGFyYQMA	1
787	25096	BAJXUwQEUGFyYQMA	1
787	25101	BApCbG9ja1F1b3RlAwA=	1
787	25106	BARCb2xkAwA=	1
787	25108	BAJXUwQEUGFyYQMA	1
787	25110	BARIZHIyAwA=	1
787	25112	BAJXUwQEUGFyYQMA	1
787	25115	BAJXUwQEUGFyYQMA	1
787	25120	BApCbG9ja1F1b3RlAwA=	1
787	25125	BANEZWwDAA==	1
787	25127	BAJXUwQEUGFyYQMA	1
787	25129	BARIZHIyAwA=	1
787	25131	BAJXUwQEUGFyYQMA	1
787	25134	BAJXUwQEUGFyYQMA	1
787	25139	BApCbG9ja1F1b3RlAwA=	1
787	25144	BANTdXADAA==	1
787	25147	BANTdWIDAA==	1
787	25149	BAJXUwQEUGFyYQMA	1
787	25151	BARIZHIyAwA=	1
787	25153	BAJXUwQEUGFyYQMA	1
787	25156	BAJXUwQEUGFyYQMA	1
787	25161	BApCbG9ja1F1b3RlAwA=	1
787	25166	BARIZHIxAwA=	1
787	25168	BAJXUwQEUGFyYQMA	1
787	25173	BApCbG9ja1F1b3RlAwA=	1
787	25178	BARIZHIyAwA=	1
787	25180	BAJXUwQEUGFyYQMA	1
787	25182	BARIZHIxAwA=	1
787	25186	BAJXUwQEUGFyYQMA	1
787	25189	BARCb2xkAwA=	1
787	25192	BARCb2xkAwA=	1
787	25195	BAJXUwQEUGFyYQMA	1
787	25198	BAhXaWtpTGluawMA	1
787	25201	BAJXUwQEUGFyYQMA	1
787	25203	BAJXUwQEUGFyYQMA	1
803	25521	BARCb2xkAwA=	30
803	25524	BARCb2xkAwA=	30
803	25527	BARCb2xkAwA=	30
803	25530	BARCb2xkAwA=	30
803	25533	BAJXUwQEUGFyYQMA	30
803	25536	BARFbXBoAwA=	30
803	25539	BAJXUwQEUGFyYQMA	30
803	25544	BApCbG9ja1F1b3RlAwA=	30
803	25554	BAhXaWtpTGluawMA	30
803	25556	BAJXUwQEUGFyYQMA	30
804	25562	BARCb2xkAwA=	30
804	25565	BARCb2xkAwA=	30
804	25568	BAJXUwQEUGFyYQMA	30
804	25571	BARFbXBoAwA=	30
804	25577	BARFbXBoAwA=	30
804	25583	BARFbXBoAwA=	30
804	25589	BARCb2xkAwA=	30
804	25592	BAJXUwQEUGFyYQMA	30
804	25595	BARCb2xkAwA=	30
804	25598	BAJXUwQEUGFyYQMA	30
804	25603	BApCbG9ja1F1b3RlAwA=	30
804	25613	BARFbXBoAwA=	30
804	25616	BAJXUwQEUGFyYQMA	30
804	25619	BAhXaWtpTGluawMA	30
804	25621	BAJXUwQEUGFyYQMA	30
805	25627	BAJXUwQEUGFyYQMA	30
805	25632	BARMaXN0AwA=	30
805	25634	BAZJbmRlbnQIBQEw	30
805	25635	BAxVbm9yZGVyZWRFbHQGAQgBKg==	30
805	25638	BARCb2xkAwA=	30
805	25642	BAZJbmRlbnQIBQEw	30
805	25643	BAxVbm9yZGVyZWRFbHQGAQgBKg==	30
805	25646	BARFbXBoAwA=	30
805	25651	BAZJbmRlbnQIBQEw	30
805	25652	BAxVbm9yZGVyZWRFbHQGAQgBKg==	30
805	25655	BARCb2xkAwA=	30
805	25659	BAZJbmRlbnQIBQEw	30
805	25660	BAxVbm9yZGVyZWRFbHQGAQgBKg==	30
805	25663	BARCb2xkAwA=	30
805	25670	BARFbXBoAwA=	30
805	25673	BARFbXBoAwA=	30
805	25676	BARFbXBoAwA=	30
805	25679	BAJXUwQEUGFyYQMA	30
805	25682	BARFbXBoAwA=	30
805	25685	BARFbXBoAwA=	30
805	25688	BAJXUwQEUGFyYQMA	30
805	25691	BARCb2xkAwA=	30
805	25694	BARCb2xkAwA=	30
805	25697	BARCb2xkAwA=	30
805	25700	BAJXUwQEUGFyYQMA	30
805	25708	BARFbXBoAwA=	30
805	25711	BARFbXBoAwA=	30
805	25716	BAJXUwQEUGFyYQMA	30
805	25719	BAhXaWtpTGluawMA	30
807	25762	BARFbXBoAwA=	30
807	25765	BARCb2xkAwA=	30
807	25768	BARCb2xkAwA=	30
807	25771	BAJXUwQEUGFyYQMA	30
807	25774	BARCb2xkAwA=	30
807	25777	BARFbXBoAwA=	30
807	25780	BAJXUwQEUGFyYQMA	30
807	25783	BAhXaWtpTGluawMA	30
807	25786	BAJXUwQEUGFyYQMA	30
806	25824	BAJXUwQEUGFyYQMA	1
806	25827	BARCb2xkAwA=	1
806	25830	BARFbXBoAwA=	1
806	25833	BARFbXBoAwA=	1
806	25836	BARCb2xkAwA=	1
806	25839	BARCb2xkAwA=	1
806	25842	BAJXUwQEUGFyYQMA	1
806	25844	BAJXUwQFSExpbmUDAA==	1
806	25848	BAhXaWtpTGluawMA	1
806	25850	BAJXUwQEUGFyYQMA	1
765	26176	BAJXUwQEUGFyYQMA	1
765	26180	BAJXUwQEUGFyYQMA	1
813	26194	BARMaW5rBgYIAXMIAWMIAXIIAWkIAXAIAXQ=	34
813	26197	BARMaW5rBgcIAS8IAXMIAWMIAXIIAWkIAXAIAXQ=	34
814	26203	BARMaW5rBgYIAXMIAWMIAXIIAWkIAXAIAXQ=	34
814	26206	BARMaW5rBgcIAS8IAXMIAWMIAXIIAWkIAXAIAXQ=	34
814	26208	BAJXUwQEUGFyYQMA	34
815	26213	BAJXUwQEUGFyYQMA	34
815	26216	BARMaW5rBgYIAXMIAWMIAXIIAWkIAXAIAXQ=	34
815	26219	BARMaW5rBgcIAS8IAXMIAWMIAXIIAWkIAXAIAXQ=	34
815	26221	BAJXUwQEUGFyYQMA	34
816	26228	BAJXUwQEUGFyYQMA	34
816	26231	BARMaW5rBgYIAXMIAWMIAXIIAWkIAXAIAXQ=	34
816	26234	BARMaW5rBgcIAS8IAXMIAWMIAXIIAWkIAXAIAXQ=	34
816	26236	BAJXUwQEUGFyYQMA	34
812	26249	BAJXUwQEUGFyYQMA	1
792	26269	BARCb2xkAwA=	1
792	26272	BAJXUwQEUGFyYQMA	1
792	26275	BARCb2xkAwA=	1
792	26278	BAJXUwQEUGFyYQMA	1
792	26282	BAJXUwQEUGFyYQMA	1
792	26287	BARFbXBoAwA=	1
792	26290	BARCb2xkAwA=	1
792	26293	BAJXUwQEUGFyYQMA	1
792	26295	BAJXUwQFSExpbmUDAA==	1
792	26297	BAJXUwQEUGFyYQMA	1
792	26300	BAhXaWtpTGluawMA	1
783	26484	BARIZHIyAwA=	1
783	26486	BAJXUwQEUGFyYQMA	1
783	26491	BAJXUwQEUGFyYQMA	1
783	26495	BAJXUwQEUGFyYQMA	1
783	26500	BAJXUwQEUGFyYQMA	1
783	26503	BARFbXBoAwA=	1
783	26506	BARFbXBoAwA=	1
783	26509	BAJXUwQEUGFyYQMA	1
783	26512	BAJXUwQEUGFyYQMA	1
783	26515	BAhXaWtpTGluawMA	1
783	26520	BARIZHIyAwA=	34
818	26529	BAJXUwQEUGFyYQMA	34
808	26684	BAJXUwQEUGFyYQMA	34
808	26687	BAJXUwQEUGFyYQMA	34
808	26692	BARMaXN0AwA=	34
808	26694	BAZJbmRlbnQIBQEw	34
808	26695	BApPcmRlcmVkRWx0BgIIATEIAS4=	34
808	26697	BAhXaWtpTGluawMA	34
808	26701	BAZJbmRlbnQIBQEw	34
808	26702	BApPcmRlcmVkRWx0BgIIATIIAS4=	34
808	26704	BAhXaWtpTGluawMA	34
808	26708	BAZJbmRlbnQIBQEx	34
808	26709	BApPcmRlcmVkRWx0BgIIATEIAS4=	34
808	26711	BAhXaWtpTGluawMA	34
808	26715	BAZJbmRlbnQIBQEx	34
808	26716	BApPcmRlcmVkRWx0BgIIATIIAS4=	34
808	26718	BAhXaWtpTGluawMA	34
808	26722	BAZJbmRlbnQIBQEx	34
808	26723	BApPcmRlcmVkRWx0BgIIATMIAS4=	34
808	26725	BAhXaWtpTGluawMA	34
808	26729	BAZJbmRlbnQIBQEw	34
808	26730	BApPcmRlcmVkRWx0BgIIATMIAS4=	34
808	26732	BAhXaWtpTGluawMA	34
808	26736	BAZJbmRlbnQIBQEx	34
808	26737	BApPcmRlcmVkRWx0BgIIATEIAS4=	34
808	26739	BAhXaWtpTGluawMA	34
808	26743	BAZJbmRlbnQIBQEx	34
808	26744	BApPcmRlcmVkRWx0BgIIATIIAS4=	34
808	26746	BAhXaWtpTGluawMA	34
808	26750	BAZJbmRlbnQIBQEx	34
808	26751	BApPcmRlcmVkRWx0BgIIATMIAS4=	34
808	26753	BAhXaWtpTGluawMA	34
808	26757	BAZJbmRlbnQIBQEx	34
808	26758	BApPcmRlcmVkRWx0BgIIATQIAS4=	34
808	26760	BAhXaWtpTGluawMA	34
808	26764	BAZJbmRlbnQIBQEx	34
808	26765	BApPcmRlcmVkRWx0BgIIATUIAS4=	34
808	26767	BAhXaWtpTGluawMA	34
808	26771	BAZJbmRlbnQIBQEw	34
808	26772	BApPcmRlcmVkRWx0BgIIATQIAS4=	34
808	26774	BAhXaWtpTGluawMA	34
808	26778	BAZJbmRlbnQIBQEx	34
808	26779	BApPcmRlcmVkRWx0BgIIATEIAS4=	34
808	26781	BAhXaWtpTGluawMA	34
808	26785	BAZJbmRlbnQIBQEx	34
808	26786	BApPcmRlcmVkRWx0BgIIATIIAS4=	34
808	26788	BAhXaWtpTGluawMA	34
808	26792	BAZJbmRlbnQIBQEx	34
808	26793	BApPcmRlcmVkRWx0BgIIATMIAS4=	34
808	26795	BAhXaWtpTGluawMA	34
808	26799	BAZJbmRlbnQIBQEx	34
808	26800	BApPcmRlcmVkRWx0BgIIATQIAS4=	34
808	26802	BAhXaWtpTGluawMA	34
808	26806	BAZJbmRlbnQIBQEx	34
808	26807	BApPcmRlcmVkRWx0BgIIATUIAS4=	34
808	26809	BAhXaWtpTGluawMA	34
808	26813	BAZJbmRlbnQIBQEw	34
808	26814	BApPcmRlcmVkRWx0BgIIATUIAS4=	34
808	26816	BAhXaWtpTGluawMA	34
808	26820	BAJXUwQEUGFyYQMA	34
808	26823	BAhXaWtpTGluawMA	34
781	26902	BARMaW5rBhMIAWgIAXQIAXQIAXAIAToIAS8IAS8IAXcIAXcIAXcIAS4IAWUIAWQIAS4IAWEIAWMIAS4IAXUIAWs=	34
781	26905	BAJXUwQEUGFyYQMA	34
781	26914	BAJXUwQEUGFyYQMA	34
781	26917	BARMaW5rBiEIAWgIAXQIAXQIAXAIAToIAS8IAS8IAWcIAXIIAW8IAXUIAXAIAXMIAS4IAWkIAW4IAWYIAS4IAWUIAWQIAS4IAWEIAWMIAS4IAXUIAWsIAS8IAWwIAWkIAW4IAWsIAXMIAS8=	34
781	26920	BAJXUwQEUGFyYQMA	34
781	26923	BAhXaWtpTGluawMA	34
788	26927	BAJXUwQEUGFyYQMA	34
788	26932	BARMaXN0AwA=	34
788	26934	BAZJbmRlbnQIBQEw	34
788	26935	BApPcmRlcmVkRWx0BgIIATEIAS4=	34
788	26940	BAZJbmRlbnQIBQEw	34
788	26941	BApPcmRlcmVkRWx0BgIIATIIAS4=	34
788	26946	BAJXUwQEUGFyYQMA	34
788	26949	BAJXUwQEUGFyYQMA	34
788	26951	BARIZHIyAwA=	34
788	26953	BAJXUwQEUGFyYQMA	34
788	26956	BAJXUwQEUGFyYQMA	34
788	26961	BApCbG9ja1F1b3RlAwA=	34
788	26966	BAhXaWtpTGluawMA	34
788	26968	BAJXUwQEUGFyYQMA	34
788	26971	BAJXUwQEUGFyYQMA	34
788	26973	BARIZHIyAwA=	34
788	26975	BAJXUwQEUGFyYQMA	34
788	26978	BAJXUwQEUGFyYQMA	34
788	26983	BApCbG9ja1F1b3RlAwA=	34
788	26988	BARMaW5rBhYIAWgIAXQIAXQIAXAIAToIAS8IAS8IAXcIAXcIAXcIAS4IAWcIAW8IAW8IAWcIAWwIAWUIAS4IAWMIAW8IAW0IAS8=	34
788	26990	BAJXUwQEUGFyYQMA	34
788	26993	BAJXUwQEUGFyYQMA	34
788	26998	BApCbG9ja1F1b3RlAwA=	34
788	27004	BARMaW5rBh4IAWgIAXQIAXQIAXAIAXMIAToIAS8IAS8IAXcIAXcIAXcIAS4IAWIIAWEIAW4IAWsIAW8IAWYIAWEIAW0IAWUIAXIIAWkIAWMIAWEIAS4IAWMIAW8IAW0IAS8=	34
788	27006	BAJXUwQEUGFyYQMA	34
788	27008	BARMaW5rBhUIAW0IAWEIAWkIAWwIAXQIAW8IAToIAWIIAWoIAWMIAUAIAWMIAXMIAS4IAXUIAW0IAWQIAS4IAWUIAWQIAXU=	34
788	27010	BAJXUwQEUGFyYQMA	34
788	27012	BAJXUwQFSExpbmUDAA==	34
788	27016	BARMaW5rBhIIAWgIAXQIAXQIAXAIAToIAS8IAS8IAXcIAXcIAXcIAS4IAXUIAW0IAWQIAS4IAWUIAWQIAXU=	34
788	27018	BAJXUwQEUGFyYQMA	34
788	27020	BAJXUwQFSExpbmUDAA==	34
788	27025	BAhXaWtpTGluawMA	34
788	27028	BAJXUwQEUGFyYQMA	34
801	27043	BAJXUwQEUGFyYQMA	34
801	27048	BARMaXN0AwA=	34
801	27050	BAZJbmRlbnQIBQEw	34
801	27051	BAxVbm9yZGVyZWRFbHQGAQgBKg==	34
801	27056	BAZJbmRlbnQIBQEw	34
801	27057	BAxVbm9yZGVyZWRFbHQGAQgBKg==	34
801	27065	BAJXUwQEUGFyYQMA	34
801	27067	BARIZHIxAwA=	34
801	27069	BAJXUwQEUGFyYQMA	34
801	27074	BARFbXBoAwA=	34
801	27077	BARFbXBoAwA=	34
801	27080	BARFbXBoAwA=	34
801	27083	BAJXUwQEUGFyYQMA	34
801	27088	BApCbG9ja1F1b3RlAwA=	34
801	27094	BARFbXBoAwA=	34
801	27097	BARFbXBoAwA=	34
801	27100	BARFbXBoAwA=	34
801	27103	BARFbXBoAwA=	34
801	27106	BARFbXBoAwA=	34
801	27109	BARFbXBoAwA=	34
801	27112	BARFbXBoAwA=	34
801	27115	BAJXUwQEUGFyYQMA	34
801	27118	BARFbXBoAwA=	34
801	27121	BARFbXBoAwA=	34
801	27124	BAJXUwQEUGFyYQMA	34
801	27126	BARIZHIxAwA=	34
801	27128	BAJXUwQEUGFyYQMA	34
801	27131	BAJXUwQEUGFyYQMA	34
801	27134	BARFbXBoAwA=	34
801	27137	BAJXUwQEUGFyYQMA	34
801	27140	BAJXUwQEUGFyYQMA	34
801	27143	BAJXUwQEUGFyYQMA	34
801	27148	BApCbG9ja1F1b3RlAwA=	34
801	27158	BAhXaWtpTGluawMA	34
801	27160	BAJXUwQEUGFyYQMA	34
765	27205	BARFbXBoAwA=	34
820	27231	BAJXUwQFSExpbmUDAA==	34
820	27233	BAJXUwQEUGFyYQMA	34
\.


--
-- Data for Name: block_label; Type: TABLE DATA; Schema: public; Owner: -
--

COPY block_label (pageid, blockid, label) FROM stdin;
776	20326	SECURITY[PROV[ACTIONS[ACTION_20070825034146[CREATE[DESC[*Start Here*],TIME[23:41:46],DATE[2007-08-24],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
780	20793	SECURITY[PROV[ACTIONS[ACTION_20070825035543[CREATE[DESC[Demo 2 Background],TIME[23:55:43],DATE[2007-08-24],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
782	20847	SECURITY[PROV[ACTIONS[ACTION_20070825040815[CREATE[DESC[Demo 2b SElinks],TIME[00:08:15],DATE[2007-08-25],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
781	21214	SECURITY[PROV[ACTIONS[ACTION_20070825042112[CREATE[DESC[Demo2aLinks],TIME[00:02:04],DATE[2007-08-25],USER[Brian]]],ACTION_20070825042112[MODIFY[DESC[Path:.->!],TIME[00:17:17],DATE[2007-08-25],USER[Brian]]],ACTION_20070825042112[MODIFY[DESC[Path:.->!],TIME[00:17:52],DATE[2007-08-25],USER[Brian]]],ACTION_20070825042112[MODIFY[DESC[Path:.->!],TIME[00:18:51],DATE[2007-08-25],USER[Brian]]],ACTION_20070825042112[MODIFY[DESC[Path:.->!],TIME[00:19:21],DATE[2007-08-25],USER[Brian]]],ACTION_20070825042112[MODIFY[DESC[Path:.->!],TIME[00:19:43],DATE[2007-08-25],USER[Brian]]],ACTION_20070825042112[MODIFY[DESC[Path:.->!],TIME[00:21:04],DATE[2007-08-25],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
784	21240	SECURITY[PROV[ACTIONS[ACTION_20070825042348[CREATE[DESC[Demo 3 Wiki Features],TIME[00:23:48],DATE[2007-08-25],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
788	22399	SECURITY[PROV[ACTIONS[ACTION_20070825141756[CREATE[DESC[Demo 3c URLs],TIME[10:17:55],DATE[2007-08-25],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
790	23689	SECURITY[PROV[ACTIONS[ACTION_20070825144217[CREATE[DESC[Demo 3d Other Features],TIME[10:42:17],DATE[2007-08-25],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
786	24542	SECURITY[PROV[ACTIONS[ACTION_20070827233726[CREATE[DESC[Demo3aTextEditing],TIME[09:55:28],DATE[2007-08-25],USER[Brian]]],ACTION_20070827233726[MODIFY[DESC[Path:.->!],TIME[19:37:21],DATE[2007-08-27],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
787	25055	SECURITY[PROV[ACTIONS[ACTION_20070827233915[CREATE[DESC[Demo3bTextFormatting],TIME[10:04:21],DATE[2007-08-25],USER[Brian]]],ACTION_20070827233915[MODIFY[DESC[Path:.->!],TIME[10:05:11],DATE[2007-08-25],USER[Brian]]],ACTION_20070827233915[MODIFY[DESC[Path:.->!],TIME[10:06:29],DATE[2007-08-25],USER[Brian]]],ACTION_20070827233915[MODIFY[DESC[Path:.->!],TIME[10:07:01],DATE[2007-08-25],USER[Brian]]],ACTION_20070827233915[MODIFY[DESC[Path:.->!],TIME[19:38:03],DATE[2007-08-27],USER[Brian]]],ACTION_20070827233915[MODIFY[DESC[Path:.->!],TIME[19:39:03],DATE[2007-08-27],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
801	25210	SECURITY[PROV[ACTIONS[ACTION_20070828020505[CREATE[DESC[Demo 4 Labels],TIME[22:05:05],DATE[2007-08-27],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
803	25517	SECURITY[PROV[ACTIONS[ACTION_20070828020743[CREATE[DESC[Demo 4b Modifying Content Revisted],TIME[22:07:43],DATE[2007-08-27],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
804	25558	SECURITY[PROV[ACTIONS[ACTION_20070828021026[CREATE[DESC[Demo 4c Modifying Access Control],TIME[22:10:26],DATE[2007-08-27],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
805	25623	SECURITY[PROV[ACTIONS[ACTION_20070828021255[CREATE[DESC[Demo 4e Access Control in Action],TIME[22:12:55],DATE[2007-08-27],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
807	25756	SECURITY[PROV[ACTIONS[ACTION_20070828021658[CREATE[DESC[Demo 4d Copy Paste Revisited],TIME[22:16:58],DATE[2007-08-27],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
806	25821	SECURITY[PROV[ACTIONS[ACTION_20070828021749[CREATE[DESC[Demo6Conclusion],TIME[22:13:55],DATE[2007-08-27],USER[Brian]]],ACTION_20070828021749[MODIFY[DESC[Path:.->!],TIME[22:17:46],DATE[2007-08-27],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
765	26172	SECURITY[PROV[ACTIONS[ACTION_20080114191806[MODIFY[DESC[Path:.->!],TIME[15:27:03],DATE[2007-08-17],USER[Brian]]],ACTION_20080114191806[CREATE[DESC[SELinksDemoRestricted],TIME[15:26:05],DATE[2007-08-17],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
765	26174	SECURITY[PROV[ACTIONS[ACTION_20080114191806[MODIFY[DESC[Path:.->!],TIME[15:27:03],DATE[2007-08-17],USER[Brian]]],ACTION_20080114191806[CREATE[DESC[SELinksDemoRestricted],TIME[15:26:05],DATE[2007-08-17],USER[Brian]]],ACTION_20080114191806[MODIFY[DESC[Path:.->.0->!],TIME[14:16:48],DATE[2008-01-14],USER[demo]]],ACTION_20080114191806[MODIFY[DESC[Path:.->.0->.->!],TIME[14:18:01],DATE[2008-01-14],USER[demo]]]]],ACL[WRITE[authors],READ[guests]]]
765	26178	SECURITY[PROV[ACTIONS[ACTION_20080114191806[RELABEL[DESC[ACL{WRITE{administrators};READ{guests}}],TIME[15:27:46],DATE[2007-08-17],USER[Brian]]]]],ACL[WRITE[administrators],READ[guests]]]
765	26182	SECURITY[PROV[ACTIONS[ACTION_20080114191807[RELABEL[DESC[ACL{WRITE{administrators};READ{administrators}}],TIME[15:27:29],DATE[2007-08-17],USER[Brian]]]]],ACL[WRITE[administrators],READ[administrators]]]
813	26191	SECURITY[PROV[ACTIONS[ACTION_20080114191958[CREATE[DESC[test xss],TIME[14:19:58],DATE[2008-01-14],USER[demo]]]]],ACL[WRITE[authors],READ[guests]]]
814	26199	SECURITY[PROV[ACTIONS[ACTION_20080114192549[CREATE[DESC[xss again],TIME[14:25:49],DATE[2008-01-14],USER[demo]]]]],ACL[WRITE[authors],READ[guests]]]
815	26210	SECURITY[PROV[ACTIONS[ACTION_20080114192634[CREATE[DESC[xss once more],TIME[14:26:34],DATE[2008-01-14],USER[demo]]]]],ACL[WRITE[authors],READ[guests]]]
816	26225	SECURITY[PROV[ACTIONS[ACTION_20080114192850[CREATE[DESC[XSS 1],TIME[14:28:50],DATE[2008-01-14],USER[demo]]]]],ACL[WRITE[authors],READ[guests]]]
812	26246	SECURITY[PROV[ACTIONS[ACTION_20080114235051[CREATE[DESC[testpagenik],TIME[14:18:55],DATE[2008-01-14],USER[demo]]],ACTION_20080114235051[MODIFY[DESC[Path:.->!],TIME[14:19:25],DATE[2008-01-14],USER[demo]]],ACTION_20080114235051[MODIFY[DESC[Path:.->!],TIME[18:50:49],DATE[2008-01-14],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
792	26264	SECURITY[PROV[ACTIONS[ACTION_20080116144825[CREATE[DESC[Demo3eCopyPaste],TIME[14:07:12],DATE[2007-08-25],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
792	26266	SECURITY[PROV[ACTIONS[ACTION_20080116144825[CREATE[DESC[Demo3eCopyPaste],TIME[14:07:12],DATE[2007-08-25],USER[Brian]]],ACTION_20080116144825[MODIFY[DESC[Path:.->.0->!],TIME[14:07:50],DATE[2007-08-25],USER[Brian]]],ACTION_20080116144825[MODIFY[DESC[Path:.->.0->.->!],TIME[09:48:20],DATE[2008-01-16],USER[demo]]]]],ACL[WRITE[authors],READ[guests]]]
792	26280	SECURITY[PROV[ACTIONS[ACTION_20080116144825[RELABEL[DESC[ACL{WRITE{guests;authors};READ{guests}}],TIME[14:07:26],DATE[2007-08-25],USER[Brian]]]]],ACL[WRITE[guests,authors],READ[guests]]]
792	26284	SECURITY[PROV[ACTIONS[ACTION_20080116144825[CREATE[DESC[Demo3eCopyPaste],TIME[14:07:12],DATE[2007-08-25],USER[Brian]]],ACTION_20080116144825[MODIFY[DESC[Path:.->.4->!],TIME[14:08:14],DATE[2007-08-25],USER[Brian]]]]],ACL[WRITE[authors],READ[guests]]]
808	26303	SECURITY[PROV[ACTIONS[ACTION_20080118160641[CREATE[DESC[Demo1Overview],TIME[22:24:42],DATE[2007-08-27],USER[Brian]]],ACTION_20080118160641[RELABEL[DESC[ACL{WRITE{authors;guests};READ{guests}}],TIME[11:06:40],DATE[2008-01-18],USER[demo]]]]],ACL[WRITE[authors,guests],READ[guests]]]
783	26482	SECURITY[PROV[ACTIONS[ACTION_20080119191954[CREATE[DESC[Demo2cCPAWiki],TIME[00:15:39],DATE[2007-08-25],USER[Brian]]],ACTION_20080119191954[MODIFY[DESC[Path:.->!],TIME[00:16:16],DATE[2007-08-25],USER[Brian]]],ACTION_20080119191954[MODIFY[DESC[Path:.->!],TIME[14:19:51],DATE[2008-01-19],USER[demo]]]]],ACL[WRITE[authors],READ[guests]]]
783	26519	SECURITY[PROV[ACTIONS[ACTION_20080119192026[RELABEL[DESC[ACL{WRITE{authors};READ{guests}}],TIME[14:20:26],DATE[2008-01-19],USER[demo]]]]],ACL[WRITE[authors],READ[guests]]]
817	26522	SECURITY[PROV[ACTIONS[ACTION_20080127214822[CREATE[DESC[Testing],TIME[16:48:22],DATE[2008-01-27],USER[demo]]]]],ACL[WRITE[authors],READ[guests]]]
818	26525	ACL[WRITE[authors],READ[guests,authors]]
819	26680	ACL[WRITE[authors],READ[guests,authors,auditors]]
820	27217	ACL[WRITE[authors,guests],READ[guests,authors]]
824	27256	ACL[WRITE[authors],READ[guests,authors]]
\.


--
-- Data for Name: page_blocks; Type: TABLE DATA; Schema: public; Owner: -
--

COPY page_blocks (blockid, pageid, parentblockid, blocktype, text, sibling, current) FROM stdin;
23744	790	23743	word	\r\n\r\n	0	t
25623	805	25623	labeled		0	t
21214	781	21214	labeled		0	t
25210	801	25210	labeled		0	t
20326	776	20326	labeled		0	t
20328	776	20326	compound		0	t
20329	776	20328	word	Welcome to the 	0	t
20330	776	20328	formatted		1	t
20331	776	20330	word	SEWiki	0	t
20332	776	20328	word	 application.	2	t
20333	776	20328	formatted		3	t
20334	776	20333	word	\r\n\r\n	0	t
20335	776	20328	word	This document serves as a demonstration and tutorial of the SEWiki system, including both the standard Wiki features and the security features. You will be guided through the process of creating and editing a Wiki document. 	4	t
20336	776	20328	formatted		5	t
20337	776	20336	word	\r\n\r\n	0	t
20338	776	20328	word	At this point, you should be logged in as the 	6	t
20339	776	20328	formatted		7	t
20340	776	20339	word	demo	0	t
20341	776	20328	word	 user using the password 	8	t
20342	776	20328	formatted		9	t
20343	776	20342	word	demopw	0	t
20344	776	20328	word	. If not, click 	10	t
20345	776	20328	formatted		11	t
20346	776	20345	word	Main menu	0	t
20347	776	20328	word	, then 	12	t
20348	776	20328	formatted		13	t
20349	776	20348	word	Logout	0	t
20350	776	20328	word	, and log back in using above username and password.	14	t
20351	776	20328	formatted		15	t
20352	776	20351	word	\r\n\r\n	0	t
20353	776	20328	word	At some steps, you will be asked to create and edit a separate page. The easiest way to do this is to use two browser windows; one for viewing the demonstration, and another for creating your own pages. You can open up a second page by right	16	t
20354	776	20328	word	-	17	t
20355	776	20328	word	clicking 	18	t
20356	776	20328	formatted		19	t
20357	776	20356	word	this link	0	t
20358	776	20328	word	, and selecting 	20	t
20359	776	20328	formatted		21	t
20360	776	20359	word	Open link in new window	0	t
20361	776	20328	word	.	22	t
20362	776	20328	formatted		23	t
20363	776	20362	word	\r\n\r\n	0	t
20364	776	20328	word	To begin, continue on to 	24	t
20365	776	20328	formatted		25	t
20366	776	20365	word	Demo 1 Overview	0	t
20367	776	20328	formatted		26	t
20368	776	20367	word	\r\n\r\n	0	t
20793	780	20793	labeled		0	t
20795	780	20793	compound		0	t
20796	780	20795	word	This section discusses the background behind the SEWiki application.	0	t
20797	780	20795	formatted		1	t
20798	780	20797	word	\r\n\r\n	0	t
20799	780	20795	word	\r	2	t
20800	780	20795	compound		3	t
20801	780	20800	word	\n	0	t
20802	780	20800	formatted		1	t
20803	780	20802	compound		0	t
20804	780	20803	formatted		0	t
20805	780	20804	formatted		0	t
20806	780	20805	compound		0	t
20807	780	20806	formatted		0	t
20808	780	20807	word	Demo 2a Links	0	t
20809	780	20806	word	\r	1	t
20810	780	20806	word	\n	2	t
20811	780	20803	formatted		1	t
20812	780	20811	formatted		0	t
20813	780	20812	compound		0	t
20814	780	20813	formatted		0	t
20815	780	20814	word	Demo 2b SELinks	0	t
20816	780	20813	word	\r	1	t
20817	780	20813	word	\n	2	t
20818	780	20803	formatted		2	t
20819	780	20818	formatted		0	t
20820	780	20819	compound		0	t
20821	780	20820	formatted		0	t
20822	780	20821	word	Demo 2c SEWiki	0	t
20823	780	20820	word	\r	1	t
20824	780	20820	word	\n	2	t
20825	780	20795	word	\r	4	t
20826	780	20795	word	\n	5	t
20847	782	20847	labeled		0	t
20849	782	20847	compound		0	t
20850	782	20849	word	SELinks is a security	0	t
20851	782	20849	word	-	1	t
20852	782	20849	word	enhanced version of Links being developed in conjunction with this Wiki. It is based on a formalism called 	2	t
20853	782	20849	formatted		3	t
20854	782	20853	word	Fable	0	t
20855	782	20849	word	. The main ideas behind the SELinks extensions are to associate 	4	t
20856	782	20849	formatted		5	t
20857	782	20856	word	security labels	0	t
20858	782	20849	word	 with data or actions. The semantics of these labels are then defined via an 	6	t
20859	782	20849	formatted		7	t
20860	782	20859	word	enforcement policy	0	t
20861	782	20849	word	. Labeled terms can only be constructed, deconstructed, and relabeled by means of the enforcement policies. SELinks is able to represent a wide variety of security policies, including access control, information flow, data provenance, trusted declassification, and security automata. 	8	t
20862	782	20849	formatted		9	t
20863	782	20862	word	\r\n\r\n	0	t
20864	782	20849	word	Next: 	10	t
20865	782	20849	formatted		11	t
21240	784	21240	labeled		0	t
21242	784	21240	compound		0	t
21243	784	21242	word	Now let us examine the various wiki features.	0	t
21244	784	21242	formatted		1	t
21245	784	21244	word	\r\n\r\n	0	t
21246	784	21242	word	\r	2	t
21247	784	21242	compound		3	t
21248	784	21247	word	\n	0	t
21249	784	21247	formatted		1	t
21250	784	21249	compound		0	t
21251	784	21250	formatted		0	t
21252	784	21251	formatted		0	t
21253	784	21252	compound		0	t
21254	784	21253	formatted		0	t
21255	784	21254	word	Demo 3a TextEditing	0	t
21256	784	21253	word	\r	1	t
21257	784	21253	word	\n	2	t
21258	784	21250	formatted		1	t
21259	784	21258	formatted		0	t
21260	784	21259	compound		0	t
21261	784	21260	formatted		0	t
21262	784	21261	word	Demo 3b Text Formatting	0	t
21263	784	21260	word	\r	1	t
21264	784	21260	word	\n	2	t
21265	784	21250	formatted		2	t
21266	784	21265	formatted		0	t
21267	784	21266	compound		0	t
21268	784	21267	formatted		0	t
21269	784	21268	word	Demo 3c URLs	0	t
21270	784	21267	word	\r	1	t
21271	784	21267	word	\n	2	t
21272	784	21250	formatted		3	t
21273	784	21272	formatted		0	t
21274	784	21273	compound		0	t
21275	784	21274	formatted		0	t
21276	784	21275	word	Demo 3d Other Features	0	t
21277	784	21274	word	\r	1	t
21278	784	21274	word	\n	2	t
21279	784	21250	formatted		4	t
21280	784	21279	formatted		0	t
21281	784	21280	compound		0	t
21282	784	21281	formatted		0	t
21283	784	21282	word	Demo 3e Copy Paste	0	t
21284	784	21281	word	\r	1	t
21285	784	21281	word	\n	2	t
21286	784	21242	formatted		4	t
21287	784	21286	word	\r\n\r\n	0	t
22399	788	22399	labeled		0	t
23689	790	23689	labeled		0	t
23691	790	23689	compound		0	t
23692	790	23691	word	In this section we examine a few more advanced features that didn't fit into the previous sections:	0	t
23693	790	23691	formatted		1	t
23694	790	23693	word	\r\n\r\n	0	t
23695	790	23691	word	\r	2	t
23696	790	23691	compound		3	t
23697	790	23696	word	\n	0	t
23698	790	23696	formatted		1	t
23699	790	23698	compound		0	t
23700	790	23699	formatted		0	t
23701	790	23700	formatted		0	t
23702	790	23701	compound		0	t
23703	790	23702	word	Images	0	t
23704	790	23702	word	\r	1	t
23705	790	23702	word	\n	2	t
23706	790	23699	formatted		1	t
23707	790	23706	formatted		0	t
23708	790	23707	compound		0	t
23709	790	23708	word	Lists	0	t
23710	790	23708	word	\r	1	t
23711	790	23708	word	\n	2	t
23712	790	23699	formatted		2	t
23713	790	23712	formatted		0	t
23714	790	23713	compound		0	t
23715	790	23714	word	Horizontal lines	0	t
23716	790	23714	word	\r	1	t
23717	790	23714	word	\n	2	t
23718	790	23699	formatted		3	t
23719	790	23718	formatted		0	t
23720	790	23719	compound		0	t
23721	790	23720	word	Escaping text	0	t
23722	790	23720	word	\r	1	t
23723	790	23720	word	\n	2	t
23724	790	23691	word	\r	4	t
23725	790	23691	word	\n	5	t
23726	790	23691	formatted		6	t
23727	790	23726	word	Images	0	t
23728	790	23691	formatted		7	t
23729	790	23728	word	\r\n\r\n	0	t
23730	790	23691	word	Images are specified similarly to external hyperlinks, but with a prepended exclamation mark:	8	t
23731	790	23691	formatted		9	t
23732	790	23731	word	\r\n\r\n	0	t
23733	790	23691	word	\r	10	t
23734	790	23691	compound		11	t
23735	790	23734	word	\n	0	t
23736	790	23734	formatted		1	t
23737	790	23736	compound		0	t
23738	790	23737	word	![alternative text] (http://www.cs.umd.edu/assets/images/logos/globe2.gif)\r\n	0	t
23739	790	23691	word	\r	12	t
23740	790	23691	word	\n	13	t
23741	790	23691	formatted		14	t
23742	790	23741	word	alternative text	0	t
23743	790	23691	formatted		15	t
23745	790	23691	word	Here, 	16	t
23746	790	23691	formatted		17	t
23747	790	23746	word	alternative text	0	t
23748	790	23691	word	 is the text that is displayed when a user accesses the page with a browser that cannot display images (e.g., text	18	t
23749	790	23691	word	-	19	t
23750	790	23691	word	 or speech	20	t
23751	790	23691	word	-	21	t
23752	790	23691	word	based). The rest of the formatting is the web address of the image.	22	t
23753	790	23691	formatted		23	t
23754	790	23753	word	\r\n\r\n	0	t
23755	790	23691	formatted		24	t
23756	790	23755	word	Lists	0	t
23757	790	23691	formatted		25	t
23758	790	23757	word	\r\n\r\n	0	t
23759	790	23691	formatted		26	t
23760	790	23759	word	Note:	0	t
23761	790	23691	word	 Lists are a bit finicky at this point. It's possible to create them and restore them, but modification doesn't always work.	27	t
23762	790	23691	formatted		28	t
23763	790	23762	word	\r\n\r\n	0	t
23765	790	23691	formatted		30	t
23766	790	23765	word	\r\n\r\n	0	t
23767	790	23691	word	To create a list, you currently must leave two blank lines, then use one of the following syntaxes:	31	t
23768	790	23691	formatted		32	t
23769	790	23768	word	\r\n\r\n	0	t
23770	790	23691	word	\r	33	t
23771	790	23691	compound		34	t
23772	790	23771	word	\n	0	t
23773	790	23771	formatted		1	t
23774	790	23773	compound		0	t
23775	790	23774	word	* Bulleted Item 1\r\n	0	t
23776	790	23774	word	* Bulleted Item 2\r\n	1	t
23777	790	23691	formatted		35	t
23778	790	23777	word	\r\n\r\n	0	t
23779	790	23691	word	\r	36	t
23780	790	23691	compound		37	t
23781	790	23780	word	\n	0	t
23782	790	23780	formatted		1	t
23783	790	23782	compound		0	t
23784	790	23783	formatted		0	t
23785	790	23784	formatted		0	t
23786	790	23785	compound		0	t
23787	790	23786	word	Bulleted Item 1	0	t
23788	790	23786	word	\r	1	t
23789	790	23786	word	\n	2	t
23790	790	23783	formatted		1	t
23791	790	23790	formatted		0	t
23792	790	23791	compound		0	t
23793	790	23792	word	Bulleted Item 2	0	t
23794	790	23792	word	\r	1	t
23795	790	23792	word	\n	2	t
23796	790	23691	formatted		38	t
23797	790	23796	word	\r\n\r\n	0	t
23798	790	23691	word	\r	39	t
23799	790	23691	compound		40	t
23800	790	23799	word	\n	0	t
23801	790	23799	formatted		1	t
23802	790	23801	compound		0	t
23803	790	23802	word	1. Numbered Item 1\r\n	0	t
23804	790	23802	word	2. Numbered Item 2\r\n	1	t
23805	790	23691	formatted		41	t
23806	790	23805	word	\r\n\r\n	0	t
23807	790	23691	word	\r	42	t
23808	790	23691	compound		43	t
23809	790	23808	word	\n	0	t
23810	790	23808	formatted		1	t
23811	790	23810	compound		0	t
23812	790	23811	formatted		0	t
23813	790	23812	formatted		0	t
23814	790	23813	compound		0	t
23815	790	23814	word	Numbered Item 1	0	t
23816	790	23814	word	\r	1	t
23817	790	23814	word	\n	2	t
23818	790	23811	formatted		1	t
23819	790	23818	formatted		0	t
23820	790	23819	compound		0	t
23821	790	23820	word	Numbered Item 2	0	t
23822	790	23820	word	\r	1	t
23823	790	23820	word	\n	2	t
23824	790	23691	formatted		44	t
23825	790	23824	word	\r\n\r\n	0	t
23826	790	23691	word	\r	45	t
23827	790	23691	word	\n	46	t
23828	790	23691	word	To make a multiple	47	t
23829	790	23691	word	-	48	t
23830	790	23691	word	level list, indent by 4 spaces:	49	t
23831	790	23691	formatted		50	t
23832	790	23831	word	\r\n\r\n	0	t
23833	790	23691	word	\r	51	t
23834	790	23691	compound		52	t
23835	790	23834	word	\n	0	t
23836	790	23834	formatted		1	t
23837	790	23836	compound		0	t
23838	790	23837	word	1. Item 1\r\n	0	t
23839	790	23837	word	    * Sub Item\r\n	1	t
23840	790	23837	word	    * Sub Item\r\n	2	t
23841	790	23837	word	2. Item 2\r\n	3	t
23842	790	23837	word	3. Item 3\r\n	4	t
23843	790	23691	formatted		53	t
23844	790	23843	word	\r\n\r\n	0	t
23845	790	23691	word	\r	54	t
23846	790	23691	compound		55	t
23847	790	23846	word	\n	0	t
23848	790	23846	formatted		1	t
23849	790	23848	compound		0	t
23850	790	23849	formatted		0	t
23851	790	23850	formatted		0	t
23852	790	23851	compound		0	t
23853	790	23852	word	Item 1	0	t
23854	790	23852	word	\r	1	t
23855	790	23852	word	\n	2	t
23856	790	23849	formatted		1	t
23857	790	23856	formatted		0	t
23858	790	23857	compound		0	t
23859	790	23858	word	Sub Item	0	t
23860	790	23858	word	\r	1	t
23861	790	23858	word	\n	2	t
23862	790	23849	formatted		2	t
23863	790	23862	formatted		0	t
23864	790	23863	compound		0	t
23865	790	23864	word	Sub Item	0	t
23866	790	23864	word	\r	1	t
23867	790	23864	word	\n	2	t
23868	790	23849	formatted		3	t
23869	790	23868	formatted		0	t
23870	790	23869	compound		0	t
23871	790	23870	word	Item 2	0	t
23872	790	23870	word	\r	1	t
23873	790	23870	word	\n	2	t
23874	790	23849	formatted		4	t
23875	790	23874	formatted		0	t
23876	790	23875	compound		0	t
23877	790	23876	word	Item 3	0	t
23878	790	23876	word	\r	1	t
23879	790	23876	word	\n	2	t
23880	790	23691	formatted		56	t
23881	790	23880	word	\r\n\r\n	0	t
23882	790	23691	formatted		57	t
23883	790	23882	word	Horizontal Lines	0	t
23884	790	23691	formatted		58	t
23885	790	23884	word	\r\n\r\n	0	t
23886	790	23691	word	You can form a horizontal line by typing six hyphens in a row:	59	t
23887	790	23691	formatted		60	t
23888	790	23887	word	\r\n\r\n	0	t
23889	790	23691	word	\r	61	t
23890	790	23691	compound		62	t
23891	790	23890	word	\n	0	t
23892	790	23890	formatted		1	t
23893	790	23892	compound		0	t
23894	790	23893	word	------\r\n	0	t
23895	790	23691	word	\r	63	t
23896	790	23691	word	\n	64	t
23897	790	23691	formatted		65	t
23898	790	23897	word	------	0	t
23899	790	23691	formatted		66	t
23900	790	23899	word	\r\n\r\n	0	t
23901	790	23691	word	\r	67	t
23902	790	23691	word	\n	68	t
23903	790	23691	formatted		69	t
23904	790	23903	word	Escaping Text	0	t
23905	790	23691	formatted		70	t
23906	790	23905	word	\r\n\r\n	0	t
23907	790	23691	word	In order to format all of the previous example, we took advantage of a feature to 	71	t
23908	790	23691	formatted		72	t
23909	790	23908	word	escape	0	t
23910	790	23691	word	 the formatting code, so it appears as normal text. To do this, you must first leave two blank lines, then use the greater	73	t
23911	790	23691	word	-	74	t
23912	790	23691	word	than character:	75	t
23913	790	23691	formatted		76	t
23914	790	23913	word	\r\n\r\n	0	t
23915	790	23691	word	\r	77	t
23916	790	23691	compound		78	t
23917	790	23916	word	\n	0	t
23918	790	23916	formatted		1	t
23919	790	23918	compound		0	t
23920	790	23919	word	>*not italicized*\r\n	0	t
23921	790	23691	formatted		79	t
23922	790	23921	word	\r\n\r\n	0	t
23923	790	23691	word	\r	80	t
23924	790	23691	compound		81	t
23925	790	23924	word	\n	0	t
23926	790	23924	formatted		1	t
23927	790	23926	compound		0	t
23928	790	23927	word	*not italicized*\r\n	0	t
23929	790	23691	word	\r	82	t
23930	790	23691	word	\n	83	t
23931	790	23691	formatted		84	t
23932	790	23931	word	------	0	t
23933	790	23691	formatted		85	t
23934	790	23933	word	\r\n\r\n	0	t
23935	790	23691	word	We discuss a final, non	86	t
23936	790	23691	word	-	87	t
23937	790	23691	word	standard, feature of SEWiki in 	88	t
23938	790	23691	formatted		89	t
23939	790	23938	word	Demo 3e Copy Paste	0	t
23940	790	23691	word	.	90	t
24542	786	24542	labeled		0	t
24543	786	24542	compound		0	t
24544	786	24543	formatted		0	t
24545	786	24544	word	Page Creation and Text Editing	0	t
24546	786	24543	formatted		1	t
24547	786	24546	word	\r\n\r\n	0	t
24548	786	24543	word	Similar to most wiki applications, SEWiki allows you to create and edit text using a web browser. 	2	t
24549	786	24543	formatted		3	t
24550	786	24549	word	\r\n\r\n	0	t
24551	786	24543	word	If you have not yet done so, 	4	t
24552	786	24543	formatted		5	t
24553	786	24552	word	open	0	t
24554	786	24543	word	 a second copy of this site, log in again as 	6	t
24555	786	24543	formatted		7	t
24556	786	24555	word	demo	0	t
24557	786	24543	word	, (password: 	8	t
24558	786	24543	formatted		9	t
24559	786	24558	word	demopw	0	t
24560	786	24543	word	). 	10	t
24561	786	24543	formatted		11	t
24562	786	24561	word	\r\n\r\n	0	t
24563	786	24543	formatted		12	t
24564	786	24563	word	Creating a New Page	0	t
24565	786	24543	formatted		13	t
24566	786	24565	word	\r\n\r\n	0	t
24567	786	24543	word	To create a new page, click 	14	t
24568	786	24543	formatted		15	t
24569	786	24568	word	Create New Page	0	t
24570	786	24543	word	. You will prompted to enter a title and the body of the text. Use 	16	t
24571	786	24543	formatted		17	t
24572	786	24571	word	My Test Page	0	t
24573	786	24543	word	 for the title, enter some plain text (avoid symbols for now) for the body, and click 	18	t
24574	786	24543	formatted		19	t
24575	786	24574	word	Save Page	0	t
24576	786	24543	word	.	20	t
24577	786	24543	formatted		21	t
24578	786	24577	word	\r\n\r\n	0	t
24579	786	24543	word	Your page, which has been saved to the database, is now displayed.	22	t
24580	786	24543	formatted		23	t
24581	786	24580	word	\r\n\r\n	0	t
24582	786	24543	formatted		24	t
24583	786	24582	word	 Editing Text 	0	t
24584	786	24543	formatted		25	t
24585	786	24584	word	\r\n\r\n	0	t
24586	786	24543	word	Editing a page is similar. Click 	26	t
24587	786	24543	formatted		27	t
24588	786	24587	word	Modify page	0	t
24589	786	24543	word	 from the options at the bottom of the page. On the next page, you will see a block containing your text; choose 	28	t
24590	786	24543	formatted		29	t
24591	786	24590	word	Edit	0	t
24592	786	24543	word	. 	30	t
24593	786	24543	formatted		31	t
24594	786	24593	word	\r\n\r\n	0	t
24595	786	24543	word	Modify your text, still avoiding symbols, and click 	32	t
24596	786	24543	formatted		33	t
24597	786	24596	word	Save WikiEdit	0	t
24598	786	24543	word	. You will be returned to the editing screen, where you should see your updated page.	34	t
24599	786	24543	formatted		35	t
24600	786	24599	word	\r\n\r\n	0	t
24601	786	24543	word	To learn how to enter formatted text, continue to 	36	t
24602	786	24543	formatted		37	t
24603	786	24602	word	Demo 3b Text Formatting	0	t
24604	786	24543	word	.	38	t
25055	787	25055	labeled		0	t
25056	787	25055	compound		0	t
25057	787	25056	word	The SEWiki application allows a wide variety of text	0	t
25058	787	25056	word	-	1	t
25059	787	25056	word	based formatting commands. 	2	t
25060	787	25056	word	\r	3	t
25061	787	25056	word	\n	4	t
25062	787	25056	word	Most formatting is done by surrounding text with a pair of matching symbols.	5	t
25063	787	25056	formatted		6	t
25064	787	25063	word	\r\n\r\n	0	t
25065	787	25056	formatted		7	t
25066	787	25065	word	Examples	0	t
25067	787	25056	formatted		8	t
25068	787	25067	word	\r\n\r\n	0	t
25069	787	25056	formatted		9	t
25070	787	25069	word	 Emphasis 	0	t
25071	787	25056	formatted		10	t
25072	787	25071	word	\r\n\r\n	0	t
25073	787	25056	word	There are two different ways to emphasize (usually, italicize) text:	11	t
25074	787	25056	formatted		12	t
25075	787	25074	word	\r\n\r\n	0	t
25076	787	25056	word	\r	13	t
25077	787	25056	compound		14	t
25078	787	25077	word	\n	0	t
25079	787	25077	formatted		1	t
25080	787	25079	compound		0	t
25081	787	25080	word	*emphasis* or _emphasis_\r\n	0	t
25082	787	25056	word	\r	15	t
25083	787	25056	word	\n	16	t
25084	787	25056	formatted		17	t
25085	787	25084	word	emphasis	0	t
25086	787	25056	word	 or 	18	t
25087	787	25056	formatted		19	t
25088	787	25087	word	emphasis	0	t
25089	787	25056	formatted		20	t
25090	787	25089	word	\r\n\r\n	0	t
25091	787	25056	formatted		21	t
25092	787	25091	word	 Bold 	0	t
25093	787	25056	formatted		22	t
25094	787	25093	word	\r\n\r\n	0	t
25095	787	25056	word	Similarly, bold uses two asterisks:	23	t
25096	787	25056	formatted		24	t
25097	787	25096	word	\r\n\r\n	0	t
25098	787	25056	word	\r	25	t
25099	787	25056	compound		26	t
25100	787	25099	word	\n	0	t
25101	787	25099	formatted		1	t
25102	787	25101	compound		0	t
25103	787	25102	word	**bold**\r\n	0	t
25104	787	25056	word	\r	27	t
25105	787	25056	word	\n	28	t
25106	787	25056	formatted		29	t
25107	787	25106	word	bold	0	t
25108	787	25056	formatted		30	t
25109	787	25108	word	\r\n\r\n	0	t
25110	787	25056	formatted		31	t
25111	787	25110	word	Strikethrough	0	t
25112	787	25056	formatted		32	t
25113	787	25112	word	\r\n\r\n	0	t
25114	787	25056	word	To strike out a word, use dashes:	33	t
25115	787	25056	formatted		34	t
25116	787	25115	word	\r\n\r\n	0	t
25117	787	25056	word	\r	35	t
25118	787	25056	compound		36	t
25119	787	25118	word	\n	0	t
25120	787	25118	formatted		1	t
25121	787	25120	compound		0	t
25122	787	25121	word	 --strikethrough--\r\n	0	t
25123	787	25056	word	\r	37	t
25124	787	25056	word	\n	38	t
25125	787	25056	formatted		39	t
25126	787	25125	word	strikethrough	0	t
25127	787	25056	formatted		40	t
25128	787	25127	word	\r\n\r\n	0	t
25129	787	25056	formatted		41	t
25130	787	25129	word	 Superscript, Subscript 	0	t
25131	787	25056	formatted		42	t
25132	787	25131	word	\r\n\r\n	0	t
25133	787	25056	word	SEWiki supports both superscript and subscript:	43	t
25134	787	25056	formatted		44	t
25135	787	25134	word	\r\n\r\n	0	t
25136	787	25056	word	\r	45	t
25137	787	25056	compound		46	t
25138	787	25137	word	\n	0	t
25139	787	25137	formatted		1	t
25140	787	25139	compound		0	t
25141	787	25140	word	^superscript^normal~subscript~\r\n	0	t
25142	787	25056	word	\r	47	t
25143	787	25056	word	\n	48	t
25144	787	25056	formatted		49	t
25145	787	25144	word	superscript	0	t
25146	787	25056	word	normal	50	t
25147	787	25056	formatted		51	t
25148	787	25147	word	subscript	0	t
25149	787	25056	formatted		52	t
25150	787	25149	word	\r\n\r\n	0	t
25151	787	25056	formatted		53	t
25152	787	25151	word	 Headers 	0	t
25153	787	25056	formatted		54	t
25154	787	25153	word	\r\n\r\n	0	t
25155	787	25056	word	Finally, SEWiki supports two weights of headers:	55	t
25156	787	25056	formatted		56	t
25157	787	25156	word	\r\n\r\n	0	t
25158	787	25056	word	\r	57	t
25159	787	25056	compound		58	t
25160	787	25159	word	\n	0	t
25161	787	25159	formatted		1	t
25162	787	25161	compound		0	t
25163	787	25162	word	 #header1#\r\n	0	t
25164	787	25056	word	\r	59	t
25165	787	25056	word	\n	60	t
25166	787	25056	formatted		61	t
25167	787	25166	word	header1	0	t
25168	787	25056	formatted		62	t
25169	787	25168	word	\r\n\r\n	0	t
25170	787	25056	word	\r	63	t
25171	787	25056	compound		64	t
25172	787	25171	word	\n	0	t
25173	787	25171	formatted		1	t
25174	787	25173	compound		0	t
25175	787	25174	word	 ##header2##\r\n	0	t
25176	787	25056	word	\r	65	t
25177	787	25056	word	\n	66	t
25178	787	25056	formatted		67	t
25179	787	25178	word	header2	0	t
25180	787	25056	formatted		68	t
25181	787	25180	word	\r\n\r\n	0	t
25182	787	25056	formatted		69	t
25183	787	25182	compound		0	t
25184	787	25183	word	Try it	0	t
25185	787	25183	word	!	1	t
25186	787	25056	formatted		70	t
25187	787	25186	word	\r\n\r\n	0	t
25188	787	25056	word	Edit your page again by clicking 	71	t
25189	787	25056	formatted		72	t
25190	787	25189	word	Edit	0	t
25191	787	25056	word	, and try out some of the above formatting.Once you're done, remember to click 	73	t
25192	787	25056	formatted		74	t
25193	787	25192	word	Save WikiEdit	0	t
25194	787	25056	word	.	75	t
25195	787	25056	formatted		76	t
25196	787	25195	word	\r\n\r\n	0	t
25197	787	25056	word	Continue on to 	77	t
25198	787	25056	formatted		78	t
25199	787	25198	word	Demo 3c URLs	0	t
25200	787	25056	word	 to learn how to make hyperlinks. 	79	t
25201	787	25056	formatted		80	t
25202	787	25201	word	\r\n\r\n	0	t
25203	787	25056	formatted		81	t
25204	787	25203	word	\r\n\r\n	0	t
23764	790	23691	word	SEWiki supports many different types of lists: both numbered and bulleted, and different levels of depth.	29	t
25517	803	25517	labeled		0	t
25519	803	25517	compound		0	t
25520	803	25519	word	Now let's modify the page. Click 	0	t
25521	803	25519	formatted		1	t
25522	803	25521	word	Modify page	0	t
25523	803	25519	word	 from the options at the bottom. On the next page, choose 	2	t
25524	803	25519	formatted		3	t
25525	803	25524	word	Edit	0	t
25526	803	25519	word	. Change the page in some fashion, and click 	4	t
25527	803	25519	formatted		5	t
25528	803	25527	word	Save WikiEdit	0	t
25529	803	25519	word	. Finally, click 	6	t
25530	803	25519	formatted		7	t
25531	803	25530	word	View all labels	0	t
25532	803	25519	word	.	8	t
25533	803	25519	formatted		9	t
25534	803	25533	word	\r\n\r\n	0	t
25535	803	25519	word	There is now a new 	10	t
25536	803	25519	formatted		11	t
25538	803	25519	word	 entry stating that the page was modified:	12	t
25539	803	25519	formatted		13	t
25540	803	25539	word	\r\n\r\n	0	t
25541	803	25519	word	\r	14	t
25542	803	25519	compound		15	t
25543	803	25542	word	\n	0	t
25544	803	25542	formatted		1	t
25545	803	25544	compound		0	t
25547	803	25545	word	.....DESC.Path:.->!\r\n	1	t
25548	803	25545	word	.....TIME.12:48:06\r\n	2	t
25549	803	25545	word	.....DATE.2007-08-17\r\n	3	t
25550	803	25545	word	.....USER.demo\r\n	4	t
25551	803	25519	word	\r	16	t
25552	803	25519	word	\n	17	t
25553	803	25519	word	Continue on to 	18	t
25554	803	25519	formatted		19	t
25555	803	25554	word	Demo 4c Modifying Access Control	0	t
25556	803	25519	formatted		20	t
25557	803	25556	word	\r\n\r\n	0	t
25558	804	25558	labeled		0	t
25560	804	25558	compound		0	t
25561	804	25560	word	To modify access control, first click 	0	t
25562	804	25560	formatted		1	t
25563	804	25562	word	Edit ACL Labels	0	t
25564	804	25560	word	. You will see that your page consists of a single labeled block. Click 	2	t
25565	804	25560	formatted		3	t
25566	804	25565	word	Edit	0	t
25567	804	25560	word	 in the red box under the Labeled title.	4	t
25568	804	25560	formatted		5	t
25569	804	25568	word	\r\n\r\n	0	t
25570	804	25560	word	Now you will see all of the available labels, and 	6	t
25571	804	25560	formatted		7	t
25572	804	25571	compound		0	t
25573	804	25572	word	READ	0	t
25574	804	25572	word	[	1	t
25576	804	25560	word	 and 	8	t
25577	804	25560	formatted		9	t
25578	804	25577	compound		0	t
25579	804	25578	word	WRITE	0	t
25580	804	25578	word	[	1	t
25582	804	25560	word	 should be selected. Using control (Windows) or command (Mac), select an additional label of 	10	t
25583	804	25560	formatted		11	t
25584	804	25583	compound		0	t
25585	804	25584	word	READ	0	t
25586	804	25584	word	[	1	t
25587	804	25584	word	auditors]	2	t
25588	804	25560	word	, and click 	12	t
25589	804	25560	formatted		13	t
25590	804	25589	word	Save Labels	0	t
25591	804	25560	word	.	14	t
25592	804	25560	formatted		15	t
25593	804	25592	word	\r\n\r\n	0	t
25594	804	25560	word	Next, click 	16	t
25595	804	25560	formatted		17	t
25596	804	25595	word	View all labels	0	t
25597	804	25560	word	. You should see that the label now contains read permission for the auditors group.	18	t
25598	804	25560	formatted		19	t
25599	804	25598	word	\r\n\r\n	0	t
25600	804	25560	word	\r	20	t
25601	804	25560	compound		21	t
25602	804	25601	word	\n	0	t
25603	804	25601	formatted		1	t
25604	804	25603	compound		0	t
25605	804	25604	word	.ACL\r\n	0	t
25607	804	25604	word	..READ\r\n	2	t
25609	804	25604	word	...auditors\r\n	4	t
25610	804	25560	word	\r	22	t
25611	804	25560	word	\n	23	t
25612	804	25560	word	Additionally, there is 	24	t
25613	804	25560	formatted		25	t
25615	804	25560	word	 label, documenting that the label was changed.	26	t
25616	804	25560	formatted		27	t
25617	804	25616	word	\r\n\r\n	0	t
25618	804	25560	word	Next 	28	t
25619	804	25560	formatted		29	t
25620	804	25619	word	Demo 4d Copy Paste Revisited	0	t
25621	804	25560	formatted		30	t
25622	804	25621	word	\r\n\r\n	0	t
25625	805	25623	compound		0	t
25626	805	25625	word	So far we have described how to view and modify labels. In this section, we demonstrate label enforcement. To start, in your second window:	0	t
25627	805	25625	formatted		1	t
25628	805	25627	word	\r\n\r\n	0	t
25629	805	25625	word	\r	2	t
25630	805	25625	compound		3	t
25631	805	25630	word	\n	0	t
25632	805	25630	formatted		1	t
25633	805	25632	compound		0	t
25634	805	25633	formatted		0	t
25635	805	25634	formatted		0	t
25636	805	25635	compound		0	t
25637	805	25636	word	Click 	0	t
25638	805	25636	formatted		1	t
25639	805	25638	word	Main menu	0	t
25640	805	25636	word	\r	2	t
25641	805	25636	word	\n	3	t
25642	805	25633	formatted		1	t
25643	805	25642	formatted		0	t
25644	805	25643	compound		0	t
25645	805	25644	word	Select 	0	t
25646	805	25644	formatted		1	t
25647	805	25646	word	Demo Restricted	0	t
25648	805	25644	word	 from the drop down menu	2	t
25649	805	25644	word	\r	3	t
25650	805	25644	word	\n	4	t
25651	805	25633	formatted		2	t
25652	805	25651	formatted		0	t
25653	805	25652	compound		0	t
25654	805	25653	word	Click 	0	t
25655	805	25653	formatted		1	t
25656	805	25655	word	Load selected page	0	t
25657	805	25653	word	\r	2	t
25658	805	25653	word	\n	3	t
25659	805	25633	formatted		3	t
25660	805	25659	formatted		0	t
25661	805	25660	compound		0	t
25662	805	25661	word	Click 	0	t
25663	805	25661	formatted		1	t
25664	805	25663	word	View all labels	0	t
25665	805	25661	word	\r	2	t
25666	805	25661	word	\n	3	t
25667	805	25625	word	\r	4	t
25668	805	25625	word	\n	5	t
25669	805	25625	word	You will be presented with a page with three lines. The first line is writable by the 	6	t
25670	805	25625	formatted		7	t
25672	805	25625	word	 group. The second line is only writable by the 	8	t
25673	805	25625	formatted		9	t
25674	805	25673	word	administrators	0	t
25675	805	25625	word	 group, of which 	10	t
25676	805	25625	formatted		11	t
25677	805	25676	word	demo	0	t
25678	805	25625	word	 is not a member. 	12	t
25679	805	25625	formatted		13	t
25680	805	25679	word	\r\n\r\n	0	t
25681	805	25625	word	The third line is only viewable by the 	14	t
25682	805	25625	formatted		15	t
25683	805	25682	word	administrators	0	t
25684	805	25625	word	 group, so the access control policy prevents it from being displayed, instead showing 	16	t
25685	805	25625	formatted		17	t
25686	805	25685	word	Access Denied	0	t
25687	805	25625	word	.	18	t
25688	805	25625	formatted		19	t
25689	805	25688	word	\r\n\r\n	0	t
25690	805	25625	word	Now we will attempt to edit the middle block, where we have read access, but no write access. In that window, click 	20	t
25691	805	25625	formatted		21	t
25692	805	25691	word	Modify Page	0	t
25693	805	25625	word	, then click 	22	t
25694	805	25625	formatted		23	t
25695	805	25694	word	Edit	0	t
25696	805	25625	word	 in the second red, Labeled block. Change the text and click 	24	t
25697	805	25625	formatted		25	t
25698	805	25697	word	Save WikiEdit	0	t
25699	805	25625	word	. 	26	t
25700	805	25625	formatted		27	t
25701	805	25700	word	\r\n\r\n	0	t
25702	805	25625	word	The access	28	t
25703	805	25625	word	-	29	t
25704	805	25625	word	control policy checks the permissions for the edit, and	30	t
25705	805	25625	word	\r	31	t
25706	805	25625	word	\n	32	t
25707	805	25625	word	disallows it with a 	33	t
25708	805	25625	formatted		34	t
25709	805	25708	word	SecurityException	0	t
25710	805	25625	word	. Click your browser's 	35	t
25711	805	25625	formatted		36	t
25712	805	25711	word	back	0	t
25713	805	25625	word	\r	37	t
25714	805	25625	word	\n	38	t
25715	805	25625	word	button to get back to the Wiki.	39	t
25716	805	25625	formatted		40	t
25717	805	25716	word	\r\n\r\n	0	t
25718	805	25625	word	Continue to 	41	t
25719	805	25625	formatted		42	t
25756	807	25756	labeled		0	t
25758	807	25756	compound		0	t
25759	807	25758	word	You should still have the prior page you copied in the copy buffer; we will now re	0	t
25760	807	25758	word	-	1	t
25761	807	25758	word	paste it into your current document. On the page that you created (	2	t
25762	807	25758	formatted		3	t
25763	807	25762	word	My Labeled Page	0	t
25764	807	25758	word	), click 	4	t
25765	807	25758	formatted		5	t
25766	807	25765	word	Modify page	0	t
25767	807	25758	word	, then click one of the 	6	t
25768	807	25758	formatted		7	t
25769	807	25768	word	Paste	0	t
25770	807	25758	word	 buttons. As before, the copied block will be pasted below the selected block.	8	t
25771	807	25758	formatted		9	t
25772	807	25771	word	\r\n\r\n	0	t
25773	807	25758	word	Next, click 	10	t
25774	807	25758	formatted		11	t
25775	807	25774	word	View all labels	0	t
25776	807	25758	word	. In the block you pasted, there is both a 	12	t
25777	807	25758	formatted		13	t
25779	807	25758	word	 label detailing the paste operation, as well as the provenance information detailing how the block was originally created.	14	t
25780	807	25758	formatted		15	t
25781	807	25780	word	\r\n\r\n	0	t
25782	807	25758	word	In section 	16	t
25783	807	25758	formatted		17	t
25784	807	25783	word	Demo 4e Access Control in Action	0	t
25785	807	25758	word	, we will examine to how the access control labels are used to enforce our access control policy.	18	t
25786	807	25758	formatted		19	t
25787	807	25786	word	\r\n\r\n	0	t
25788	807	25758	word	\r	20	t
25789	807	25758	word	\n	21	t
25821	806	25821	labeled		0	t
25822	806	25821	compound		0	t
25823	806	25822	word	You have now seen all of the features of the SEWiki system. This concludes the tutorial. 	0	t
25824	806	25822	formatted		1	t
25825	806	25824	word	\r\n\r\n	0	t
25826	806	25822	word	If you wish, you can delete the sample pages you created. Click on 	2	t
25827	806	25822	formatted		3	t
25828	806	25827	word	Main menu	0	t
25829	806	25822	word	, select the name of the page you created (	4	t
25830	806	25822	formatted		5	t
25831	806	25830	word	My Test Page	0	t
25832	806	25822	word	 or 	6	t
25833	806	25822	formatted		7	t
25834	806	25833	word	My Labeled Page	0	t
25835	806	25822	word	), click 	8	t
25836	806	25822	formatted		9	t
25837	806	25836	word	Load Selected Page	0	t
25838	806	25822	word	, and finally, click 	10	t
25839	806	25822	formatted		11	t
25840	806	25839	word	Delete page	0	t
25841	806	25822	word	.	12	t
25842	806	25822	formatted		13	t
25843	806	25842	word	\r\n\r\n	0	t
25844	806	25822	formatted		14	t
25845	806	25844	word	------	0	t
25846	806	25822	word	\r	15	t
25847	806	25822	word	\n	16	t
25848	806	25822	formatted		17	t
25849	806	25848	word	Demo 1 Overview	0	t
25850	806	25822	formatted		18	t
25851	806	25850	word	\r\n\r\n	0	t
25720	805	25719	word	Demo 5 Conclusion	0	t
20866	782	20865	word	Demo 2c SEWiki	0	t
25671	805	25670	word	authors	0	t
25537	803	25536	word	PROV MODIFY	0	t
25546	803	25545	word	...ACTION_20070817164806.MODIFY\r	0	t
25575	804	25572	word	guests]	2	t
25581	804	25578	word	authors]	2	t
25606	804	25604	word	..WRITE.authors\r	1	t
25608	804	25604	word	...guests\r	3	t
25614	804	25613	word	PROV RELABEL	0	t
25778	807	25777	word	PROV COPY	0	t
26172	765	26172	labeled		0	\N
26173	765	26172	compound		0	\N
26174	765	26173	labeled		0	\N
26176	765	26173	formatted		1	\N
26177	765	26176	word	\r\n\r\n	0	\N
26178	765	26173	labeled		2	\N
26179	765	26178	word	the second section is readable by readers, but writable only by administrators.	0	\N
26180	765	26173	formatted		3	\N
26181	765	26180	word	\r\n\r\n	0	\N
26182	765	26173	labeled		4	\N
26183	765	26182	word	the third section is only readable and writable by administrators.	0	\N
26191	813	26191	labeled		0	\N
26193	813	26191	compound		0	\N
26194	813	26193	formatted		0	\N
26195	813	26194	word	script	0	\N
26196	813	26193	word	 alert('hello'); 	1	\N
26197	813	26193	formatted		2	\N
26198	813	26197	word	/script	0	\N
26199	814	26199	labeled		0	\N
26201	814	26199	compound		0	\N
26202	814	26201	word	> 	0	\N
26203	814	26201	formatted		1	\N
26204	814	26203	word	script	0	\N
26205	814	26201	word	 alert('hello'); 	2	\N
26206	814	26201	formatted		3	\N
26207	814	26206	word	/script	0	\N
26208	814	26201	formatted		4	\N
26209	814	26208	word	\r\n\r\n	0	\N
26210	815	26210	labeled		0	\N
26212	815	26210	compound		0	\N
26213	815	26212	formatted		0	\N
26214	815	26213	word	\r\n\r\n	0	\N
26215	815	26212	word	> 	1	\N
26216	815	26212	formatted		2	\N
26217	815	26216	word	script	0	\N
26218	815	26212	word	 alert('hello'); 	3	\N
26219	815	26212	formatted		4	\N
26220	815	26219	word	/script	0	\N
26221	815	26212	formatted		5	\N
26222	815	26221	word	\r\n\r\n	0	\N
26223	815	26212	word	\r	6	\N
26224	815	26212	word	\n	7	\N
26225	816	26225	labeled		0	\N
26227	816	26225	compound		0	\N
26228	816	26227	formatted		0	\N
26229	816	26228	word	\r\n\r\n	0	\N
26230	816	26227	word	 > 	1	\N
26231	816	26227	formatted		2	\N
26232	816	26231	word	script	0	\N
26233	816	26227	word	 alert('hello'); 	3	\N
26234	816	26227	formatted		4	\N
26235	816	26234	word	/script	0	\N
26236	816	26227	formatted		5	\N
26237	816	26236	word	\r\n\r\n	0	\N
26238	816	26227	word	\r	6	\N
26239	816	26227	word	\n	7	\N
26246	812	26246	labeled		0	\N
26247	812	26246	compound		0	\N
26248	812	26247	word	foobar	0	\N
26249	812	26247	formatted		1	\N
26250	812	26249	word	\r\n\r\n	0	\N
26251	812	26247	word	Brian modified this page.	2	\N
26264	792	26264	labeled		0	\N
26265	792	26264	compound		0	\N
26266	792	26265	labeled		0	\N
26267	792	26266	compound		0	\N
26268	792	26267	word	One novel feature of the SEWiki is the ability to copy and paste blocks from one document to another. To try this, click 	0	\N
26269	792	26267	formatted		1	\N
26270	792	26269	word	Modify Page	0	\N
26271	792	26267	word	 on this page.	2	\N
26272	792	26267	formatted		3	\N
26273	792	26272	word	\r\n\r\n	0	\N
26274	792	26267	word	Next, click 	4	\N
26275	792	26267	formatted		5	\N
26276	792	26275	word	Copy	0	\N
26277	792	26267	word	 next to the labeled block below:	6	\N
26278	792	26265	formatted		1	\N
26279	792	26278	word	\r\n\r\n	0	\N
26280	792	26265	labeled		2	\N
26281	792	26280	word	This test block demonstrates the copy/paste functionality of the SEWiki.	0	\N
26282	792	26265	formatted		3	\N
26283	792	26282	word	\r\n\r\n	0	\N
26284	792	26265	labeled		4	\N
26285	792	26284	compound		0	\N
26286	792	26285	word	On the page your created (	0	\N
26287	792	26285	formatted		1	\N
26288	792	26287	word	My Test Page	0	\N
26289	792	26285	word	), click 	2	\N
26290	792	26285	formatted		3	\N
26291	792	26290	word	Paste	0	\N
26292	792	26285	word	. The page should be pasted below the text you created.	4	\N
26293	792	26285	formatted		5	\N
26294	792	26293	word	\r\n\r\n	0	\N
26295	792	26285	formatted		6	\N
26296	792	26295	word	------	0	\N
26297	792	26285	formatted		7	\N
26298	792	26297	word	\r\n\r\n	0	\N
26299	792	26285	word	We have demonstrated all the basic wiki features. Continue to 	8	\N
26300	792	26285	formatted		9	\N
26301	792	26300	word	Demo 4 Labels	0	\N
26302	792	26285	word	 to begin learning about the security features of the SEWiki.	10	\N
26303	808	26303	labeled		0	\N
26482	783	26482	labeled		0	\N
26483	783	26482	compound		0	\N
26484	783	26483	formatted		0	\N
26485	783	26484	word	Features	0	\N
26486	783	26483	formatted		1	\N
26487	783	26486	word	\r\n\r\n	0	\N
26488	783	26483	word	The SEWiki has many standard wiki features, including text	2	\N
26489	783	26483	word	-	3	\N
26490	783	26483	word	based formatting, and internal and external linking. In addition, it implements access control and data provenance policies.	4	\N
26491	783	26483	formatted		5	\N
26492	783	26491	word	\r\n\r\n	0	\N
26495	783	26483	formatted		7	\N
26496	783	26495	word	\r\n\r\n	0	\N
26497	783	26483	word	The SEWiki is currently implemented as 3,500 lines of Links code. It uses security labels and policies based on those of SELinks; however, these are currently implemented at the user	8	\N
26498	783	26483	word	-	9	\N
26499	783	26483	word	level, rather than being baked into the language itself. 	10	\N
26500	783	26483	formatted		11	\N
26501	783	26500	word	\r\n\r\n	0	\N
26502	783	26483	word	Wiki documents are composed of 	12	\N
26503	783	26483	formatted		13	\N
26504	783	26503	word	blocks	0	\N
26505	783	26483	word	, which can range from an entire page to a single word. Blocks are also the primary unit for Labeled data; any block can be enclosed by a 	14	\N
26506	783	26483	formatted		15	\N
26507	783	26506	word	LabeledBlock	0	\N
26508	783	26483	word	 consisting of a Label and a block labeled by that label.	16	\N
26509	783	26483	formatted		17	\N
26510	783	26509	word	\r\n\r\n	0	\N
26511	783	26483	word	Work is in progress on getting the SEWiki code to check and run using the full SELinks compiler.	18	\N
26512	783	26483	formatted		19	\N
26513	783	26512	word	\r\n\r\n	0	\N
26514	783	26483	word	Next: 	20	\N
26515	783	26483	formatted		21	\N
26516	783	26515	word	Demo 3 Wiki Features	0	\N
26517	783	26483	word	\r	22	\N
26518	783	26483	word	\n	23	\N
26519	783	26483	labeled		6	\N
26520	783	26519	formatted		0	\N
26521	783	26520	word	Implementation	0	\N
26522	817	26522	labeled		0	\N
26524	817	26522	word	Testing 1 2 3...	0	\N
26525	818	26525	labeled		0	\N
26527	818	26525	compound		0	\N
26528	818	26527	word	While listening to Michael Hick's talk at Stony Brook.....	0	\N
26529	818	26527	formatted		1	\N
26530	818	26529	word	\r\n\r\n	0	\N
26680	819	26680	labeled		0	\N
26681	819	26680	word		0	\N
26682	808	26303	compound		0	\N
26683	808	26682	word	This page contains the complete overview of this document.	0	\N
26684	808	26682	formatted		1	\N
26685	808	26684	word	\r\n\r\n	0	\N
26686	808	26682	word	Note that any user can edit this page.	2	\N
26687	808	26682	formatted		3	\N
26688	808	26687	word	\r\n\r\n	0	\N
26689	808	26682	word	\r	4	\N
26690	808	26682	compound		5	\N
26691	808	26690	word	\n	0	\N
26692	808	26690	formatted		1	\N
26693	808	26692	compound		0	\N
26694	808	26693	formatted		0	\N
26695	808	26694	formatted		0	\N
26696	808	26695	compound		0	\N
26697	808	26696	formatted		0	\N
26698	808	26697	word	Demo 1 Overview	0	\N
26699	808	26696	word	\r	1	\N
26700	808	26696	word	\n	2	\N
26701	808	26693	formatted		1	\N
26702	808	26701	formatted		0	\N
26703	808	26702	compound		0	\N
26704	808	26703	formatted		0	\N
26705	808	26704	word	Demo 2 Background	0	\N
26706	808	26703	word	\r	1	\N
26707	808	26703	word	\n	2	\N
26708	808	26693	formatted		2	\N
26709	808	26708	formatted		0	\N
26710	808	26709	compound		0	\N
26711	808	26710	formatted		0	\N
26712	808	26711	word	Demo 2a Links	0	\N
26713	808	26710	word	\r	1	\N
26714	808	26710	word	\n	2	\N
26715	808	26693	formatted		3	\N
26716	808	26715	formatted		0	\N
26717	808	26716	compound		0	\N
26718	808	26717	formatted		0	\N
26719	808	26718	word	Demo 2b SELinks	0	\N
26720	808	26717	word	\r	1	\N
26721	808	26717	word	\n	2	\N
26722	808	26693	formatted		4	\N
26723	808	26722	formatted		0	\N
26724	808	26723	compound		0	\N
26725	808	26724	formatted		0	\N
26726	808	26725	word	Demo 2c SEWiki	0	\N
26727	808	26724	word	\r	1	\N
26728	808	26724	word	\n	2	\N
26729	808	26693	formatted		5	\N
26730	808	26729	formatted		0	\N
26731	808	26730	compound		0	\N
26732	808	26731	formatted		0	\N
26733	808	26732	word	Demo 3 Wiki Features	0	\N
26734	808	26731	word	\r	1	\N
26735	808	26731	word	\n	2	\N
26736	808	26693	formatted		6	\N
26737	808	26736	formatted		0	\N
26738	808	26737	compound		0	\N
26739	808	26738	formatted		0	\N
26740	808	26739	word	Demo 3a TextEditing	0	\N
26741	808	26738	word	\r	1	\N
26742	808	26738	word	\n	2	\N
26743	808	26693	formatted		7	\N
26744	808	26743	formatted		0	\N
26745	808	26744	compound		0	\N
26746	808	26745	formatted		0	\N
26747	808	26746	word	Demo 3b Text Formatting	0	\N
26748	808	26745	word	\r	1	\N
26749	808	26745	word	\n	2	\N
26750	808	26693	formatted		8	\N
26751	808	26750	formatted		0	\N
26752	808	26751	compound		0	\N
26753	808	26752	formatted		0	\N
26754	808	26753	word	Demo 3c URLs	0	\N
26755	808	26752	word	\r	1	\N
26756	808	26752	word	\n	2	\N
26757	808	26693	formatted		9	\N
26758	808	26757	formatted		0	\N
26759	808	26758	compound		0	\N
26760	808	26759	formatted		0	\N
26761	808	26760	word	Demo 3d Other Features	0	\N
26762	808	26759	word	\r	1	\N
26763	808	26759	word	\n	2	\N
26764	808	26693	formatted		10	\N
26765	808	26764	formatted		0	\N
26766	808	26765	compound		0	\N
26767	808	26766	formatted		0	\N
26768	808	26767	word	Demo 3e Copy Paste	0	\N
26769	808	26766	word	\r	1	\N
26770	808	26766	word	\n	2	\N
26771	808	26693	formatted		11	\N
26772	808	26771	formatted		0	\N
26773	808	26772	compound		0	\N
26774	808	26773	formatted		0	\N
26775	808	26774	word	Demo 4 Labels	0	\N
26776	808	26773	word	\r	1	\N
26777	808	26773	word	\n	2	\N
26778	808	26693	formatted		12	\N
26779	808	26778	formatted		0	\N
26780	808	26779	compound		0	\N
26781	808	26780	formatted		0	\N
26782	808	26781	word	Demo 4a Creating a Page Revisited	0	\N
26783	808	26780	word	\r	1	\N
26784	808	26780	word	\n	2	\N
26785	808	26693	formatted		13	\N
26786	808	26785	formatted		0	\N
26787	808	26786	compound		0	\N
26788	808	26787	formatted		0	\N
26789	808	26788	word	Demo 4b Modifying Content Revisited	0	\N
26790	808	26787	word	\r	1	\N
26791	808	26787	word	\n	2	\N
26792	808	26693	formatted		14	\N
26793	808	26792	formatted		0	\N
26794	808	26793	compound		0	\N
26795	808	26794	formatted		0	\N
26796	808	26795	word	Demo 4c Modifying Access Control	0	\N
26797	808	26794	word	\r	1	\N
26798	808	26794	word	\n	2	\N
26799	808	26693	formatted		15	\N
26800	808	26799	formatted		0	\N
26801	808	26800	compound		0	\N
26802	808	26801	formatted		0	\N
26803	808	26802	word	Demo 4d Copy Paste Revisited	0	\N
26804	808	26801	word	\r	1	\N
26805	808	26801	word	\n	2	\N
26806	808	26693	formatted		16	\N
26807	808	26806	formatted		0	\N
26808	808	26807	compound		0	\N
26809	808	26808	formatted		0	\N
26810	808	26809	word	Demo 4e Access Control in Action	0	\N
26811	808	26808	word	\r	1	\N
26812	808	26808	word	\n	2	\N
26813	808	26693	formatted		17	\N
26814	808	26813	formatted		0	\N
26815	808	26814	compound		0	\N
26816	808	26815	formatted		0	\N
26817	808	26816	word	Demo 5 Conclusion	0	\N
26818	808	26815	word	\r	1	\N
26819	808	26815	word	\n	2	\N
26820	808	26682	formatted		6	\N
26821	808	26820	word	\r\n\r\n	0	\N
26822	808	26682	word	Let's begin with 	7	\N
26823	808	26682	formatted		8	\N
26824	808	26823	word	Demo 2 Background	0	\N
26825	808	26682	word	.	9	\N
26900	781	21214	compound		0	\N
26901	781	26900	word	The web programming language Links is currently being developed at the 	0	\N
26902	781	26900	formatted		1	\N
26903	781	26902	word	University of Edinburgh	0	\N
26904	781	26900	word	. One of the primary goals of Links is to provide a single language for all three tiers of web programming: web browsing, web serving, and database access. 	2	\N
26905	781	26900	formatted		3	\N
26906	781	26905	word	\r\n\r\n	0	\N
26907	781	26900	word	Links code is compiled into client	4	\N
26908	781	26900	word	-	5	\N
26909	781	26900	word	side Javascript on the client, server	6	\N
26910	781	26900	word	-	7	\N
26911	781	26900	word	side code, and database	8	\N
26912	781	26900	word	-	9	\N
26913	781	26900	word	level SQL code.	10	\N
26914	781	26900	formatted		11	\N
26915	781	26914	word	\r\n\r\n	0	\N
26916	781	26900	word	More details can be found at the 	12	\N
26917	781	26900	formatted		13	\N
26918	781	26917	word	Links Home Page	0	\N
26919	781	26900	word	.	14	\N
26920	781	26900	formatted		15	\N
26921	781	26920	word	\r\n\r\n	0	\N
26922	781	26900	word	Next: 	16	\N
26923	781	26900	formatted		17	\N
26924	781	26923	word	Demo 2b SELinks	0	\N
26925	788	22399	compound		0	\N
26926	788	26925	word	In most wiki systems, there are two types of hyperlinks:	0	\N
26927	788	26925	formatted		1	\N
26928	788	26927	word	\r\n\r\n	0	\N
26929	788	26925	word	\r	2	\N
26930	788	26925	compound		3	\N
26931	788	26930	word	\n	0	\N
26932	788	26930	formatted		1	\N
26933	788	26932	compound		0	\N
26934	788	26933	formatted		0	\N
26935	788	26934	formatted		0	\N
26936	788	26935	compound		0	\N
26937	788	26936	word	Internal (to other pages inside the wiki)	0	\N
26938	788	26936	word	\r	1	\N
26939	788	26936	word	\n	2	\N
26940	788	26933	formatted		1	\N
26941	788	26940	formatted		0	\N
26942	788	26941	compound		0	\N
26943	788	26942	word	External (to pages outside the wiki)	0	\N
26944	788	26942	word	\r	1	\N
26945	788	26942	word	\n	2	\N
26946	788	26925	formatted		4	\N
26947	788	26946	word	\r\n\r\n	0	\N
26948	788	26925	word	The SEWiki application supports both types.	5	\N
26949	788	26925	formatted		6	\N
26950	788	26949	word	\r\n\r\n	0	\N
26951	788	26925	formatted		7	\N
26952	788	26951	word	Internal Links	0	\N
26953	788	26925	formatted		8	\N
26954	788	26953	word	\r\n\r\n	0	\N
26955	788	26925	word	Internal links link between pages of the wiki. To create one, surround the title of the page you wish to link to in double brackets:	9	\N
26956	788	26925	formatted		10	\N
26957	788	26956	word	\r\n\r\n	0	\N
26958	788	26925	word	\r	11	\N
26959	788	26925	compound		12	\N
26960	788	26959	word	\n	0	\N
26961	788	26959	formatted		1	\N
26962	788	26961	compound		0	\N
26963	788	26962	word	[[My Test Page]]\r\n	0	\N
26964	788	26925	word	\r	13	\N
26965	788	26925	word	\n	14	\N
26966	788	26925	formatted		15	\N
26967	788	26966	word	My Test Page	0	\N
26968	788	26925	formatted		16	\N
26969	788	26968	word	\r\n\r\n	0	\N
26970	788	26925	word	If a page with that title already exists, the link will take you there. If no page with that name exists, clicking on the link will prompt you to create the page.	17	\N
26971	788	26925	formatted		18	\N
26972	788	26971	word	\r\n\r\n	0	\N
26973	788	26925	formatted		19	\N
26974	788	26973	word	External Links	0	\N
26975	788	26925	formatted		20	\N
26976	788	26975	word	\r\n\r\n	0	\N
26977	788	26925	word	External links are to any web site on the Internet. They have a slightly more complex syntax:	21	\N
26978	788	26925	formatted		22	\N
26979	788	26978	word	\r\n\r\n	0	\N
26980	788	26925	word	\r	23	\N
26981	788	26925	compound		24	\N
26982	788	26981	word	\n	0	\N
26983	788	26981	formatted		1	\N
26984	788	26983	compound		0	\N
26985	788	26984	word	[Google] (http://www.google.com/)\r\n	0	\N
26986	788	26925	word	\r	25	\N
26987	788	26925	word	\n	26	\N
26988	788	26925	formatted		27	\N
26989	788	26988	word	Google	0	\N
26990	788	26925	formatted		28	\N
26991	788	26990	word	\r\n\r\n	0	\N
26992	788	26925	word	Note that any protocol that your web browser supports can be used (e.g., https, mailto):	29	\N
26993	788	26925	formatted		30	\N
26994	788	26993	word	\r\n\r\n	0	\N
26995	788	26925	word	\r	31	\N
26996	788	26925	compound		32	\N
26997	788	26996	word	\n	0	\N
26998	788	26996	formatted		1	\N
26999	788	26998	compound		0	\N
27000	788	26999	word	[Bank of America] (https://www.bankofamerica.com/)\r\n	0	\N
27001	788	26999	word	[My email] (mailto:bjc@cs.umd.edu)\r\n	1	\N
27002	788	26925	word	\r	33	\N
27003	788	26925	word	\n	34	\N
27004	788	26925	formatted		35	\N
27005	788	27004	word	Bank of America	0	\N
27006	788	26925	formatted		36	\N
27007	788	27006	word	\r\n\r\n	0	\N
27008	788	26925	formatted		37	\N
27009	788	27008	word	My email	0	\N
27010	788	26925	formatted		38	\N
27011	788	27010	word	\r\n\r\n	0	\N
27012	788	26925	formatted		39	\N
27013	788	27012	word	------	0	\N
27014	788	26925	word	\r	40	\N
27015	788	26925	word	\n	41	\N
27016	788	26925	formatted		42	\N
27017	788	27016	word	University of Maryland	0	\N
27018	788	26925	formatted		43	\N
27019	788	27018	word	\r\n\r\n	0	\N
27020	788	26925	formatted		44	\N
27021	788	27020	word	------	0	\N
27022	788	26925	word	\r	45	\N
27023	788	26925	word	\n	46	\N
27024	788	26925	word	Let's continue to examine other Wiki features in 	47	\N
27025	788	26925	formatted		48	\N
27026	788	27025	word	Demo 3d Other Features	0	\N
27027	788	26925	word	.	49	\N
27028	788	26925	formatted		50	\N
27029	788	27028	word	\r\n\r\n	0	\N
27041	801	25210	compound		0	\N
27042	801	27041	word	The SEWiki currently supports two types of labels:	0	\N
27043	801	27041	formatted		1	\N
27044	801	27043	word	\r\n\r\n	0	\N
27045	801	27041	word	\r	2	\N
27046	801	27041	compound		3	\N
27047	801	27046	word	\n	0	\N
27048	801	27046	formatted		1	\N
27049	801	27048	compound		0	\N
27050	801	27049	formatted		0	\N
27051	801	27050	formatted		0	\N
27052	801	27051	compound		0	\N
27053	801	27052	word	access control (ACL)	0	\N
27054	801	27052	word	\r	1	\N
27055	801	27052	word	\n	2	\N
27056	801	27049	formatted		1	\N
27057	801	27056	formatted		0	\N
27058	801	27057	compound		0	\N
27059	801	27058	word	data provenance (PROV)	0	\N
27060	801	27058	word	\r	1	\N
27061	801	27058	word	\n	2	\N
27062	801	27041	word	\r	4	\N
27063	801	27041	word	\n	5	\N
27064	801	27041	word	In the next few sections, we detail the format of these labels, and describe how to view, modify, and interact with them.	6	\N
27065	801	27041	formatted		7	\N
27066	801	27065	word	\r\n\r\n	0	\N
27067	801	27041	formatted		8	\N
27068	801	27067	word	Access Control Labels	0	\N
27069	801	27041	formatted		9	\N
27070	801	27069	word	\r\n\r\n	0	\N
27071	801	27041	word	Access control labels are used to enforce who and how data can be viewed and modified. In the case of the SEWiki, data refers to particular blocks on a page. Currently, access control is group	10	\N
27072	801	27041	word	-	11	\N
27073	801	27041	word	based, where a group is a list of users. Access control labels begin with the string 	12	\N
27074	801	27041	formatted		13	\N
27075	801	27074	word	ACL	0	\N
27076	801	27041	word	, and contain a list of groups with 	14	\N
27077	801	27041	formatted		15	\N
27078	801	27077	word	read	0	\N
27079	801	27041	word	 access, and as list of groups with 	16	\N
27080	801	27041	formatted		17	\N
27081	801	27080	word	write	0	\N
27082	801	27041	word	 access. A sample access control label representation is:	18	\N
27083	801	27041	formatted		19	\N
27084	801	27083	word	\r\n\r\n	0	\N
27085	801	27041	word	\r	20	\N
27086	801	27041	compound		21	\N
27087	801	27086	word	\n	0	\N
27088	801	27086	formatted		1	\N
27089	801	27088	compound		0	\N
27090	801	27089	word	ACL[READ[guests, authors], WRITE[authors]]\r\n	0	\N
27091	801	27041	word	\r	22	\N
27092	801	27041	word	\n	23	\N
27093	801	27041	word	This label mentions two groups, 	24	\N
27094	801	27041	formatted		25	\N
27095	801	27094	word	guests	0	\N
27096	801	27041	word	 and 	26	\N
27097	801	27041	formatted		27	\N
27098	801	27097	word	authors	0	\N
27099	801	27041	word	. It grants 	28	\N
27100	801	27041	formatted		29	\N
27101	801	27100	word	READ	0	\N
27102	801	27041	word	 access to both the 	30	\N
27103	801	27041	formatted		31	\N
27104	801	27103	word	guests	0	\N
27105	801	27041	word	 and 	32	\N
27106	801	27041	formatted		33	\N
27107	801	27106	word	authors	0	\N
27108	801	27041	word	 groups, and 	34	\N
27109	801	27041	formatted		35	\N
27110	801	27109	word	WRITE	0	\N
27111	801	27041	word	 access just to the 	36	\N
27112	801	27041	formatted		37	\N
27113	801	27112	word	authors	0	\N
27114	801	27041	word	 group.	38	\N
27115	801	27041	formatted		39	\N
27116	801	27115	word	\r\n\r\n	0	\N
27117	801	27041	word	The 	40	\N
27118	801	27041	formatted		41	\N
27119	801	27118	word	authors	0	\N
27120	801	27041	word	 are those users who have logged in, while 	42	\N
27121	801	27041	formatted		43	\N
27122	801	27121	word	guests	0	\N
27123	801	27041	word	 have not.	44	\N
27124	801	27041	formatted		45	\N
27125	801	27124	word	\r\n\r\n	0	\N
27126	801	27041	formatted		46	\N
27127	801	27126	word	Provenance Labels	0	\N
27128	801	27041	formatted		47	\N
27129	801	27128	word	\r\n\r\n	0	\N
27130	801	27041	word	Data provenance labels record all actions to a block, to record when, how, and by whom pages were modified.	48	\N
27131	801	27041	formatted		49	\N
27132	801	27131	word	\r\n\r\n	0	\N
27133	801	27041	word	A provenance label, notated 	50	\N
27134	801	27041	formatted		51	\N
27135	801	27134	word	PROV	0	\N
27136	801	27041	word	, signifies a list of actions which have occured at a particular block. These actions currently include page creation ( CREATE ), block (re)labeling ( RELABEL ), block modification ( MODIFY ), and block copy/pasting ( COPY ).	52	\N
27137	801	27041	formatted		53	\N
27138	801	27137	word	\r\n\r\n	0	\N
27139	801	27041	word	Each action in a provenance label includes the operation type, the name of user who performed the action, the date and time the action occurred, and an optional description of the label.	54	\N
27140	801	27041	formatted		55	\N
27141	801	27140	word	\r\n\r\n	0	\N
27142	801	27041	word	Provenance labels look something like:	56	\N
27143	801	27041	formatted		57	\N
27144	801	27143	word	\r\n\r\n	0	\N
27145	801	27041	word	\r	58	\N
27146	801	27041	compound		59	\N
27147	801	27146	word	\n	0	\N
27148	801	27146	formatted		1	\N
27149	801	27148	compound		0	\N
27150	801	27149	word	PROV.ACTIONS.ACTION_20070825022208.LABEL\r\n	0	\N
27151	801	27149	word	....DESC.ACL{WRITE{administrators};READ{readers}}\r\n	1	\N
27152	801	27149	word	....TIME.15:27:46\r\n	2	\N
27153	801	27149	word	....DATE.2007-08-17\r\n	3	\N
27154	801	27149	word	....USER.Brian\r\n	4	\N
27155	801	27041	word	\r	60	\N
27156	801	27041	word	\n	61	\N
27157	801	27041	word	Next: 	62	\N
27158	801	27041	formatted		63	\N
27159	801	27158	word	Demo 4a Creating a Page Revisited	0	\N
27160	801	27041	formatted		64	\N
27161	801	27160	word	\r\n\r\n	0	\N
27203	765	26174	compound		0	\N
27204	765	27203	word	This page is divided into three sections. This first section is writable by writers (	0	\N
27205	765	27203	formatted		1	\N
27206	765	27205	word	authors	0	\N
27207	765	27203	word	?),	2	\N
27217	820	27217	labeled		0	\N
27227	820	27217	compound		0	\N
27228	820	27227	word	This is a test page with labels.	0	\N
27229	820	27227	word	\r	1	\N
27230	820	27227	word	\n	2	\N
27231	820	27227	formatted		3	\N
27232	820	27231	word	------	0	\N
27233	820	27227	formatted		4	\N
27234	820	27233	word	\r\n\r\n	0	\N
27235	820	27227	word	More information is needed to complete this page.	5	\N
27256	824	27256	labeled		0	\N
27258	824	27256	word	what's up	0	\N
\.


--
-- Data for Name: pages; Type: TABLE DATA; Schema: public; Owner: -
--

COPY pages (pageid, creator, title) FROM stdin;
776	30	*Start Here*
780	30	Demo 2 Background
781	30	Demo 2a Links
784	30	Demo 3 Wiki Features
786	30	Demo 3a TextEditing
787	30	Demo 3b Text Formatting
788	30	Demo 3c URLs
790	30	Demo 3d Other Features
792	30	Demo 3e Copy Paste
765	30	Demo Restricted
801	30	Demo 4 Labels
804	30	Demo 4c Modifying Access Control
805	30	Demo 4e Access Control in Action
807	30	Demo 4d Copy Paste Revisited
808	30	Demo 1 Overview
782	30	Demo 2b SELinks
783	30	Demo 2c SEWiki
803	30	Demo 4b Modifying Content Revisited
806	30	Demo 5 Conclusion
812	34	test page nik
813	34	test xss
814	34	xss again
815	34	xss once more
816	34	XSS 1
817	34	Testing
818	34	Trying Wiki
819	34	
820	34	Demo 4a Creating a Page with Labels
824	34	hello
\.


--
-- Data for Name: tag_user_xref; Type: TABLE DATA; Schema: public; Owner: -
--

COPY tag_user_xref (tagid, userid) FROM stdin;
1	30
1	32
1	31
1	2
1	1
2	1
2	2
2	30
2	31
2	32
2	33
2	34
3	34
3	32
3	31
3	30
3	2
3	1
6	30
\.


--
-- Data for Name: tags; Type: TABLE DATA; Schema: public; Owner: -
--

COPY tags (tagid, "owner", name) FROM stdin;
1	1	administrators
4	1	auditors
6	30	Brian
3	1	authors
2	1	guests
\.


--
-- Data for Name: users; Type: TABLE DATA; Schema: public; Owner: -
--

COPY users (name, "password", credential, userid) FROM stdin;
admin	adminpw	0	1
reader	readerpw	50	33
Brian	Brianpw	47	30
Mike	Mikepw	49	32
Cody	Codypw	48	31
Nik	Nikpw	0	2
demo	demopw	51	34
\.


--
-- Name: pages_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY pages
    ADD CONSTRAINT pages_pkey PRIMARY KEY (pageid);


--
-- Name: pk_block_format; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY block_format
    ADD CONSTRAINT pk_block_format PRIMARY KEY (pageid, blockid, userid);


--
-- Name: pk_page_blocks; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY page_blocks
    ADD CONSTRAINT pk_page_blocks PRIMARY KEY (blockid, pageid);


--
-- Name: pk_tag_user; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY tag_user_xref
    ADD CONSTRAINT pk_tag_user PRIMARY KEY (tagid, userid);


--
-- Name: tags_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY tags
    ADD CONSTRAINT tags_pkey PRIMARY KEY (tagid);


--
-- Name: users_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY users
    ADD CONSTRAINT users_pkey PRIMARY KEY (userid);


--
-- Name: bf_foreign_key; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY block_format
    ADD CONSTRAINT bf_foreign_key FOREIGN KEY (blockid, pageid) REFERENCES page_blocks(blockid, pageid) ON DELETE CASCADE;


--
-- Name: bl_foreign_key; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY block_label
    ADD CONSTRAINT bl_foreign_key FOREIGN KEY (blockid, pageid) REFERENCES page_blocks(blockid, pageid) ON DELETE CASCADE;


--
-- Name: block_format_userid_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY block_format
    ADD CONSTRAINT block_format_userid_fkey FOREIGN KEY (userid) REFERENCES users(userid) ON DELETE CASCADE;


--
-- Name: page_blocks_pageid_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY page_blocks
    ADD CONSTRAINT page_blocks_pageid_fkey FOREIGN KEY (pageid) REFERENCES pages(pageid) ON DELETE CASCADE;


--
-- Name: pages_creator_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY pages
    ADD CONSTRAINT pages_creator_fkey FOREIGN KEY (creator) REFERENCES users(userid);


--
-- Name: pk_parent; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY page_blocks
    ADD CONSTRAINT pk_parent FOREIGN KEY (parentblockid, pageid) REFERENCES page_blocks(blockid, pageid) ON DELETE CASCADE;


--
-- Name: tag_user_xref_tagid_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY tag_user_xref
    ADD CONSTRAINT tag_user_xref_tagid_fkey FOREIGN KEY (tagid) REFERENCES tags(tagid);


--
-- Name: tag_user_xref_userid_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY tag_user_xref
    ADD CONSTRAINT tag_user_xref_userid_fkey FOREIGN KEY (userid) REFERENCES users(userid);


--
-- Name: tags_owner_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY tags
    ADD CONSTRAINT tags_owner_fkey FOREIGN KEY ("owner") REFERENCES users(userid);


--
-- Name: public; Type: ACL; Schema: -; Owner: -
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM selinks;
GRANT ALL ON SCHEMA public TO selinks;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- PostgreSQL database dump complete
--

